<?xml version="1.0" encoding="UTF-8"?>

<!--  Copyright 2010,2015 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 30/03/2015
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-dev@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->


<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"> 
    
    <xsl:include href="dxbox.xsl" />
    <xsl:include href="top_right.xsl" />
    <xsl:include href="footer.xsl" />
    <xsl:include href="res.xsl" />
    
    <!--Properties-->
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
 
    <xsl:template name="string-replace-all">
        <xsl:param name="text" />
        <xsl:param name="replace" />
        <xsl:param name="by" />
        <xsl:choose>
            <xsl:when test="contains($text, $replace)">
                <xsl:value-of select="substring-before($text,$replace)" />
                <xsl:value-of select="$by" />
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text"
                                    select="substring-after($text,$replace)" />
                    <xsl:with-param name="replace" select="$replace" />
                    <xsl:with-param name="by" select="$by" />
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$text" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <!--Variables & parameters declaration-->
    <xsl:param name="base_db_export_path" />
    <xsl:variable name="language" select="item/language/isocode"/>
    <xsl:variable name="formatUri" select="concat(item/uristandard,'/',item/uriname,'.',$language,'.')" />
    <xsl:variable name="languagefile" select="document(concat('../gui-languages/',$language,'.xml'))" />
    <xsl:variable name='newline'>&lt;br/&gt;</xsl:variable>
    
    <!--Stylesheet-->
    <xsl:template match="/">
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>
        <html>
            <xsl:attribute name="lang">
                <xsl:value-of select="$language" />
            </xsl:attribute>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
                <title>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='code-list']"/>
                    <xsl:text>-</xsl:text>
                    <xsl:value-of select="item/label"/>
                </title>
                <xsl:call-template name="res">
                    <xsl:with-param name="base_res_uri" select="item/register/registry/uri"/>
                    <xsl:with-param name="base_language" select="$language"/>
                </xsl:call-template>
                <xsl:call-template name="linkalternatecompleted">
                    <xsl:with-param name="base_format_uri" select="$formatUri"/>
                    <xsl:with-param name="base_language" select="$language"/>
                    <xsl:with-param name="base_title" select="item/label"/>
                </xsl:call-template>
            </head>            
            <body>
                <header>
                    <div id="topright">
                        <xsl:call-template name="top_right"/>
                    </div>
                    <div id="breadctxt">
                        <a href="http://ec.europa.eu/index_en.htm">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='ec']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a href="http://inspire.ec.europa.eu/">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='inspire']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a>
                            <xsl:attribute name="href" >
                                <xsl:value-of select="item/register/registry/uri"/>
                            </xsl:attribute>    
                            <xsl:value-of select="item/register/registry/label"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a>
                            <xsl:attribute name="href" >
                                <xsl:value-of select="item/register/uri"/>
                            </xsl:attribute>
                            <xsl:value-of select="item/register/label"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <span>
                            <xsl:value-of select="item/label" />
                        </span>
                    </div>
                </header>
                
                <article class="exp">
                    <xsl:apply-templates select="item"/>
                </article>
                
                <footer>
                    <xsl:call-template name="footer">
                        <xsl:with-param name="base_res_uri" select="item/register/registry/uri"/>
                    </xsl:call-template>
                </footer>
                
                <xsl:call-template name="dxbox"/>
                
            </body>
        </html>
    </xsl:template>
    
    <xsl:template match="item">
        
        <h2>  
            <xsl:value-of select="label" />
        </h2>
        
        <!-- Id and Version -->
        <p>
            <span class="csm">
                <xsl:value-of select="$languagefile/guilanguage/item[@key='id']"/>:</span>  
        </p>
        <div class="dcsm">
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uri"/>       
                </xsl:attribute>    
                <xsl:value-of select="uri"/>
            </a>
        </div>
        
        <xsl:if test="thisversion != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='this-version']"/>:
                </span> 
            </p>
            <div class="dcsm">
                <a>
                    <xsl:attribute name="href">
                        <xsl:value-of select="thisversion/uri"/>       
                    </xsl:attribute>    
                    <xsl:value-of select="thisversion/uri"/>
                </a>
            </div>
        </xsl:if>
        
        <xsl:if test="latestversion != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='latest-version']"/>:
                </span> 
            </p>
            <div class="dcsm">
                <a>
                    <xsl:attribute name="href">
                        <xsl:value-of select="latestversion/uri"/>       
                    </xsl:attribute>    
                    <xsl:value-of select="latestversion/uri"/>
                </a>
            </div>
        </xsl:if>
        
        <xsl:if test="previousversions != ''">
            <p>
                <xsl:choose>
                    <xsl:when test="count(//previousversions/version) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='previous-version']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="previousversions/version/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="previousversions/version/uri"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='previous-versions']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="previousversions/version">
                                    <li>  
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="uri"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>        
        <br/>
        
        <!-- Label, Definition, Description -->
        <xsl:if test="label != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>:
                    <xsl:choose>
                        <xsl:when test="$language != label/@language">
                            <xsl:variable name="notavailable" select="$languagefile/guilanguage/item[@key='not-available-in']"/>   
                            <br/>
                            <span class="sml">
                                <xsl:text>[</xsl:text> 
                                <xsl:value-of select="$notavailable" disable-output-escaping="yes"/>
                                <xsl:text>]</xsl:text>
                            </span>
                            <br/>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                </span> 
                <strong>
                    <xsl:value-of select="label" />
                </strong>
            </p>
        </xsl:if>
        
        <xsl:if test="definition != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='definition']"/>:
                    <xsl:choose>
                        <xsl:when test="$language != definition/@language">
                            <xsl:variable name="notavailable" select="$languagefile/guilanguage/item[@key='not-available-in']"/>   
                            <br/>
                            <span class="sml">
                                <xsl:text>[</xsl:text> 
                                <xsl:value-of select="$notavailable" disable-output-escaping="yes"/>
                                <xsl:text>]</xsl:text>
                            </span>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                </span>
            </p>    
            <div class="dcsm">
                <xsl:variable name="tmp" select="definition"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>            
            <div class="clft"></div>
        </xsl:if>
        
        <xsl:if test="description != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='description']"/>:
                    <xsl:choose>
                        <xsl:when test="$language != description/@language">
                            <xsl:variable name="notavailable" select="$languagefile/guilanguage/item[@key='not-available-in']"/>   
                            <br/>
                            <span class="sml">
                                <xsl:text>[</xsl:text> 
                                <xsl:value-of select="$notavailable" disable-output-escaping="yes"/>
                                <xsl:text>]</xsl:text>
                            </span>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                </span>
            </p>     
            <div class="dcsm">
                <xsl:variable name="tmp" select="description"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>     
            <div class="clft"></div>
        </xsl:if>
        <br/>
                
        <!--Theme and Application schema -->   
        <xsl:if test="customattributes/customattribute[name/text()='Theme'] != ''">
                    
            <xsl:if test="customattributes/customattribute[name/text()='Theme']/values != ''">
                <xsl:choose>
                    <xsl:when test="count(customattributes/customattribute[name/text()='Theme']/values/value) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='theme']"/>:</span>  
                        </p>
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="customattributes/customattribute[name/text()='Theme']/values/value/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="customattributes/customattribute[name/text()='Theme']/values/value/label"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='theme']"/>:</span>  
                        </p>
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="customattributes/customattribute[name/text()='Theme']/values/value">
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
            <br/>
        </xsl:if>        
        
        <xsl:if test="customattributes/customattribute[name/text()='ApplicationSchema'] != ''">
                    
            <xsl:if test="customattributes/customattribute[name/text()='ApplicationSchema']/values != ''">
                <xsl:choose>
                    <xsl:when test="count(customattributes/customattribute[name/text()='ApplicationSchema']/values/value) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='application-schema']"/>:</span>  
                        </p>
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="customattributes/customattribute[name/text()='ApplicationSchema']/values/value/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="customattributes/customattribute[name/text()='ApplicationSchema']/values/value/label"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='application-schema']"/>:</span>  
                        </p>
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="customattributes/customattribute[name/text()='ApplicationSchema']/values/value">
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
            <br/>
        </xsl:if>       
    
        <br/>
        
        <!--Extensibility, Governance Level, Status-->
        <xsl:variable name="registry_uri" select="register/registry/uri"></xsl:variable>
        
        <xsl:if test="customattributes/customattribute[name/text()='Extensibility'] != ''">
       
            <xsl:if test="customattributes/customattribute[name/text()='Extensibility']/values != ''">
                <xsl:choose>
                    <xsl:when test="count(customattributes/customattribute[name/text()='Extensibility']/values/value) = 1">
                                    
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='extensibility']"/>:
                            </span>
                        </p>
                        <xsl:variable name="extensibility_label" select="customattributes/customattribute[name/text()='Extensibility']/values/value/uriname"></xsl:variable>
                        <xsl:variable name="extensibility_url" select="concat($registry_uri,'/extensibility/', $extensibility_label)"/>
                        <xsl:variable name="extensible_name_label" select="concat('extensible-', $extensibility_label,'-label')"/>
                                    
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="$extensibility_url"/>
                                </xsl:attribute>    
                                <xsl:value-of select="$languagefile/guilanguage/item[@key=$extensible_name_label]"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='extensibility']"/>:
                            </span>
                        </p>
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="customattributes/customattribute[name/text()='Extensibility']/values/value">
                                    <xsl:variable name="extensibility_label" select="uriname"></xsl:variable>
                                    <xsl:variable name="extensibility_url" select="concat(register/registry/uri,'/extensibility/', $extensibility_label)"/>
                                    <xsl:variable name="extensible_name_label" select="concat('extensible-', $extensibility_label,'-label')"/>
                                        
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="$extensibility_url"/>
                                            </xsl:attribute>    
                                            <xsl:value-of select="$languagefile/guilanguage/item[@key=$extensible_name_label]"/>
                                        </a>
                                    </li>            
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
        </xsl:if>
        
        
        <xsl:if test="customattributes/customattribute[name/text()='GovernanceLevel'] != ''">
       
            <xsl:if test="customattributes/customattribute[name/text()='GovernanceLevel']/values != ''">
                <xsl:choose>
                    <xsl:when test="count(customattributes/customattribute[name/text()='GovernanceLevel']/values/value) = 1">
                                    
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='governance-level-label']"/>:
                            </span>
                        </p>
                        <xsl:variable name="governance_uriname" select="customattributes/customattribute[name/text()='GovernanceLevel']/values/value/uriname"></xsl:variable>
                        <xsl:variable name="governance_url" select="concat($registry_uri,'/governance-level/', $governance_uriname)"/>
                        <xsl:variable name="governance_label" select="concat($governance_uriname,'-label')"/>
                                    
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="$governance_url"/>
                                </xsl:attribute>    
                                <xsl:value-of select="$languagefile/guilanguage/item[@key=$governance_label]"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='governance-level-label']"/>:
                            </span>
                        </p>
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="customattributes/customattribute[name/text()='GovernanceLevel']/values/value">
                                    <xsl:variable name="governance_uriname" select="uriname"></xsl:variable>
                                    <xsl:variable name="governance_url" select="concat($registry_uri,'/governance-level/', $governance_uriname)"/>
                                    <xsl:variable name="governance_label" select="concat($governance_uriname,'-label')"/>
                                                
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="$governance_url"/>
                                            </xsl:attribute>    
                                            <xsl:value-of select="$languagefile/guilanguage/item[@key=$governance_label]"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
        </xsl:if>
        
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='status']"/>:</span>
            <xsl:variable name="status_uri" select="status/uri"/>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="status/baseuri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="status/uriname"/>
                </xsl:attribute>    
                <xsl:value-of select="status/label"/>
            </a>
        </p>
        <br/>
		
        <!-- Parents, Predecessor, Successor -->
        <xsl:if test="parents != ''">            
            <p>
                <xsl:choose>
                    <xsl:when test="count(//parents/parent) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='parent']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="parents/parent/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="parents/parent/label"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='parents']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="parents/parent">
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>
    
        <xsl:if test="predecessors != ''">
            <p>
                <xsl:choose>
                    <xsl:when test="count(//predecessors/predecessor) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='predecessor']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="predecessors/predecessor/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="predecessors/predecessor/label"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='predecessors']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="predecessors/predecessor">
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>
        
        <xsl:if test="successors != ''">
            <p>
                <xsl:choose>
                    <xsl:when test="count(//successors/successor) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='successor']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="successors/successor/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="successors/successor/label"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='successors']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="successors/successor">
                                    <li>  
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>
    
        <xsl:if test="parents != '' or predecessors != '' or successors != ''">
            <br/>
        </xsl:if>
    
        <!--Other formats-->
        <xsl:variable name="downloadFormat" select="$languagefile/guilanguage/item[@key='download-format']"/>
        <p>
            <xsl:variable name="myVarXML">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'XML'" />
                </xsl:call-template>
            </xsl:variable>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='other-formats']"/>:</span>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>xml</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt xml</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'XML'"/>
                <span>(Re3gistry)</span>
            </a>
            <xsl:variable name="myVarISO">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'ISO 19135 XML'" />
                </xsl:call-template>
            </xsl:variable>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>iso19135xml</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt iso</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'XML'"/>
                <sup>beta</sup>
                <span>(ISO 19135)</span>
            </a>
            <xsl:variable name="myVarRDF">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'RDF/XML'" />
                </xsl:call-template>
            </xsl:variable>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>rdf</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt rdf</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'RDF/XML'"/>
                <sup>beta</sup>
            </a>
            <xsl:variable name="myVarJSON">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'JSON'" />
                </xsl:call-template>
            </xsl:variable>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>json</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt json</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'JSON'"/>
            </a>
            <xsl:variable name="myVarATOM">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'ATOM'" />
                </xsl:call-template>
            </xsl:variable>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>atom</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt atom</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'Atom'"/>
            </a>
            <xsl:if test="collection != ''">
                <xsl:variable name="myVarCSV" select="$languagefile/guilanguage/item[@key='download-table-content']"/>
                <a>
                    <xsl:attribute name="data-tooltip">
                        <xsl:value-of select="$myVarCSV"/>
                    </xsl:attribute>
                    <xsl:attribute name="data-tooltip-position">
                        <xsl:text>bottom</xsl:text>
                    </xsl:attribute>
                    <xsl:attribute name="href">
                        <xsl:value-of select="$formatUri"/>
                        <xsl:text>csv</xsl:text>       
                    </xsl:attribute>
                    <xsl:attribute name="class">
                        <xsl:text>fmt csv</xsl:text>                      
                    </xsl:attribute>
                    <xsl:value-of select="'CSV'"/>
                    <sup>beta</sup>
                </a>
            </xsl:if>
            <xsl:if test="children != ''">
                <xsl:variable name="myVarCSV" select="$languagefile/guilanguage/item[@key='download-table-content']"/>
                <a>
                    <xsl:attribute name="data-tooltip">
                        <xsl:value-of select="$myVarCSV"/>
                    </xsl:attribute>
                    <xsl:attribute name="data-tooltip-position">
                        <xsl:text>bottom</xsl:text>
                    </xsl:attribute>
                    <xsl:attribute name="href">
                        <xsl:value-of select="$formatUri"/>
                        <xsl:text>csv</xsl:text>       
                    </xsl:attribute>
                    <xsl:attribute name="class">
                        <xsl:text>fmt csv</xsl:text>                      
                    </xsl:attribute>
                    <xsl:value-of select="'CSV'"/>
                </a>
            </xsl:if>
        </p> 

        <xsl:if test="customattributes/customattribute[name/text()='Document'] != ''">
            <br/>        
            <br/>
            <h3>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='code-values']"/></h3>
         
            <xsl:if test="customattributes/customattribute[name/text()='Document']/values != ''">
                <xsl:choose>
                    <xsl:when test="count(customattributes/customattribute[name/text()='Document']/values/value) = 1">
                                    
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='values_externally_codelist_defined']"/>:
                            </span>
                        </p>
                        <xsl:variable name="documentUri" select="customattributes/customattribute[name/text()='Document']/values/value/uri"></xsl:variable>
                        <xsl:variable name="documentLabel" select="customattributes/customattribute[name/text()='Document']/values/value/label"></xsl:variable>
                                    
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href" select="$documentUri"/>
                                <xsl:value-of select="$documentLabel"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='values_externally_codelist_defined']"/>:
                            </span>
                        </p>
                    
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="customattributes/customattribute[name/text()='Document']/values/value">
                                                
                                    <xsl:variable name="documentUri" select="uri"></xsl:variable>
                                    <xsl:variable name="documentLabel" select="label"></xsl:variable>
                                                
                                    <li>
                                        <a>
                                            <xsl:attribute name="href" select="$documentUri"/>
                                            <xsl:value-of select="$documentLabel"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
                
        </xsl:if>

        <!--Codelistvalue-->
        <xsl:if test="collection != ''">
            <br/>        
            <br/>
            <h3>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='code-values']"/>
            </h3>         
                    
            <div class="tb_cont">
                
                <xsl:choose>
                    <xsl:when test="count(//collection/item/parents) != 0">
                        <table id= "tbl">
                            <thead>
                                <tr>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='parent']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='status']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='governance-level-label']"/>
                                    </th>
                                </tr>  
                            </thead>          
                            <xsl:for-each select="collection/item"> 
                                <xsl:variable name="statusUri" select="concat(status/baseuri, '/', status/uriname)"/>                  
                                
                                <tr>
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="uri"/>
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </td>   
                                    <td>
                                        <xsl:for-each select="parents/parent">
                                            <li>
                                                <a>
                                                    <xsl:attribute name="href">
                                                        <xsl:value-of select="uri"/>       
                                                    </xsl:attribute>    
                                                    <xsl:value-of select="label"/>
                                                </a>
                                            </li>             
                                        </xsl:for-each>
                                    </td> 
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="$statusUri"/>
                                            <xsl:value-of select="status/label"/>
                                        </a>
                                    </td> 
                                    <td>
                                        <xsl:variable name="registry_uri" select="register/registry/uri"></xsl:variable>
        
                                        <xsl:if test="customattributes/customattribute[name/text()='GovernanceLevel'] != ''">
       
                                            <xsl:if test="customattributes/customattribute[name/text()='GovernanceLevel']/values != ''">
                                                <xsl:choose>
                                                    <xsl:when test="count(customattributes/customattribute[name/text()='GovernanceLevel']/values/value) = 1">
                                    
                                                        <xsl:variable name="governance_uriname" select="customattributes/customattribute[name/text()='GovernanceLevel']/values/value/uriname"></xsl:variable>
                                                        <xsl:variable name="governance_url" select="concat($registry_uri,'/governance-level/', $governance_uriname)"/>
                                                        <xsl:variable name="governance_label" select="concat($governance_uriname,'-label')"/>
                                    
                                                        <a>
                                                            <xsl:attribute name="href">
                                                                <xsl:value-of select="$governance_url"/>
                                                            </xsl:attribute>    
                                                            <xsl:value-of select="$languagefile/guilanguage/item[@key=$governance_label]"/>
                                                        </a>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <ul>
                                                            <xsl:for-each select="customattributes/customattribute[name/text()='GovernanceLevel']/values/value">
                                                                <xsl:variable name="governance_uriname" select="uriname"></xsl:variable>
                                                                <xsl:variable name="governance_url" select="concat($registry_uri,'/governance-level/', $governance_uriname)"/>
                                                                <xsl:variable name="governance_label" select="concat($governance_uriname,'-label')"/>
                                                
                                                                <li>
                                                                    <a>
                                                                        <xsl:attribute name="href">
                                                                            <xsl:value-of select="$governance_url"/>
                                                                        </xsl:attribute>    
                                                                        <xsl:value-of select="$languagefile/guilanguage/item[@key=$governance_label]"/>
                                                                    </a>
                                                                </li>             
                                                            </xsl:for-each>
                                                        </ul>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:if>
                
                                        </xsl:if>
                                    </td>   
                                </tr>
                            </xsl:for-each>
                        </table>
                    </xsl:when>
                    <xsl:otherwise>
                        <table id= "tbl">
                            <thead>
                                <tr>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='status']"/>
                                    </th>
                                    <th>
                                        <xsl:value-of select="$languagefile/guilanguage/item[@key='governance-level-label']"/>
                                    </th>
                                </tr>  
                            </thead>          
                            <xsl:for-each select="collection/item">
                                <xsl:variable name="statusUri" select="concat(status/baseuri, '/', status/uriname)"/>                
                                <tr>
                                    <td>
                                        <a>
                                            <xsl:attribute name="href" select="uri"/>
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </td>   
                                    <td width="15%">
                                        <a>
                                            <xsl:attribute name="href" select="$statusUri"/>
                                            <xsl:value-of select="status/label"/>
                                        </a>
                                    </td>    
                                    <td>
                                        <xsl:variable name="registry_uri" select="register/registry/uri"></xsl:variable>
        
                                        <xsl:if test="customattributes/customattribute[name/text()='GovernanceLevel'] != ''">
       
                                            <xsl:if test="customattributes/customattribute[name/text()='GovernanceLevel']/values != ''">
                                                <xsl:choose>
                                                    <xsl:when test="count(customattributes/customattribute[name/text()='GovernanceLevel']/values/value) = 1">
                                    
                                                        <xsl:variable name="governance_uriname" select="customattributes/customattribute[name/text()='GovernanceLevel']/values/value/uriname"></xsl:variable>
                                                        <xsl:variable name="governance_url" select="concat($registry_uri,'/governance-level/', $governance_uriname)"/>
                                                        <xsl:variable name="governance_label" select="concat($governance_uriname,'-label')"/>
                                    
                                                        <a>
                                                            <xsl:attribute name="href">
                                                                <xsl:value-of select="$governance_url"/>
                                                            </xsl:attribute>    
                                                            <xsl:value-of select="$languagefile/guilanguage/item[@key=$governance_label]"/>
                                                        </a>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <ul>
                                                            <xsl:for-each select="customattributes/customattribute[name/text()='GovernanceLevel']/values/value">
                                                                <xsl:variable name="governance_uriname" select="uriname"></xsl:variable>
                                                                <xsl:variable name="governance_url" select="concat($registry_uri,'/governance-level/', $governance_uriname)"/>
                                                                <xsl:variable name="governance_label" select="concat($governance_uriname,'-label')"/>
                                                
                                                                <li>
                                                                    <a>
                                                                        <xsl:attribute name="href">
                                                                            <xsl:value-of select="$governance_url"/>
                                                                        </xsl:attribute>    
                                                                        <xsl:value-of select="$languagefile/guilanguage/item[@key=$governance_label]"/>
                                                                    </a>
                                                                </li>             
                                                            </xsl:for-each>
                                                        </ul>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:if>
                
                                        </xsl:if>
                                    </td>   
                                </tr>
                            </xsl:for-each>
                        </table>
                    </xsl:otherwise>
                </xsl:choose>
                
            </div>
        </xsl:if>
        
        
        <!--Parent same itemclass-->
        <!--Table-->
        <xsl:if test="children != ''">
            <br/>        
            <br/>
            <h3>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='code-list']"/>
            </h3>     
                    
            <div class="tb_cont">
                <table id = "tbl"> 
                    <thead>
                        <tr>
                            <th>
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>
                            </th>
                            <th>
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='theme']"/>
                            </th>
                            <th>
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='application-schema']"/>
                            </th>
                            <th>
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='status']"/>
                            </th>
                        </tr>  
                    </thead>          
                    <xsl:for-each select="children/item">                
                        <tr>
                            <td>
                                <a>
                                    <xsl:attribute name="href" select="uri"/>
                                    <xsl:value-of select="label"/>
                                </a>
                            </td>
                            
                            
                            <td>
                                <xsl:if test="customattributes/customattribute[name/text()='Theme'] != ''">
                    
                                    <xsl:if test="customattributes/customattribute[name/text()='Theme']/values != ''">
                                        <xsl:choose>
                                            <xsl:when test="count(customattributes/customattribute[name/text()='Theme']/values/value) = 1">
                                                <a>
                                                    <xsl:attribute name="href">
                                                        <xsl:value-of select="customattributes/customattribute[name/text()='Theme']/values/value/uri"/>       
                                                    </xsl:attribute>    
                                                    <xsl:value-of select="customattributes/customattribute[name/text()='Theme']/values/value/label"/>
                                                </a>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <ul>
                                                    <xsl:for-each select="customattributes/customattribute[name/text()='Theme']/values/value">
                                                        <li>
                                                            <a>
                                                                <xsl:attribute name="href">
                                                                    <xsl:value-of select="uri"/>       
                                                                </xsl:attribute>    
                                                                <xsl:value-of select="label"/>
                                                            </a>
                                                        </li>             
                                                    </xsl:for-each>
                                                </ul>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:if>
                                </xsl:if>        
                            </td>   
                            
                            <td>
                                <xsl:if test="customattributes/customattribute[name/text()='ApplicationSchema'] != ''">
                    
                                    <xsl:if test="customattributes/customattribute[name/text()='ApplicationSchema']/values != ''">
                                        <xsl:choose>
                                            <xsl:when test="count(customattributes/customattribute[name/text()='ApplicationSchema']/values/value) = 1">
                                                <a>
                                                    <xsl:attribute name="href">
                                                        <xsl:value-of select="customattributes/customattribute[name/text()='ApplicationSchema']/values/value/uri"/>       
                                                    </xsl:attribute>    
                                                    <xsl:value-of select="customattributes/customattribute[name/text()='ApplicationSchema']/values/value/label"/>
                                                </a>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <ul>
                                                    <xsl:for-each select="customattributes/customattribute[name/text()='ApplicationSchema']/values/value">
                                                        <li>
                                                            <a>
                                                                <xsl:attribute name="href">
                                                                    <xsl:value-of select="uri"/>       
                                                                </xsl:attribute>    
                                                                <xsl:value-of select="label"/>
                                                            </a>
                                                        </li>             
                                                    </xsl:for-each>
                                                </ul>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:if>
                                </xsl:if>       
                            </td>
                              
                            <td width="15%">
                                <a>
                                    <xsl:attribute name="href">
                                        <xsl:value-of select="status/baseuri"/>
                                        <xsl:text>/</xsl:text>
                                        <xsl:value-of select="status/uriname"/>
                                    </xsl:attribute>    
                                    <xsl:value-of select="status/label"/>
                                </a>
                            </td>
                        </tr>
                    </xsl:for-each>
                </table>
            </div>
        </xsl:if>
        
    </xsl:template>
</xsl:stylesheet>