<?xml version="1.0" encoding="UTF-8"?>

<!--  Copyright 2010,2015 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 30/03/2015
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-dev@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->


<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"> 
    
    <xsl:include href="dxbox.xsl" />
    <xsl:include href="top_right.xsl" />
    <xsl:include href="footer.xsl" />
    <xsl:include href="res.xsl" />
    
    <!--Properties-->
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    
    <xsl:template name="string-replace-all">
        <xsl:param name="text" />
        <xsl:param name="replace" />
        <xsl:param name="by" />
        <xsl:choose>
            <xsl:when test="contains($text, $replace)">
                <xsl:value-of select="substring-before($text,$replace)" />
                <xsl:value-of select="$by" />
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text"
                                    select="substring-after($text,$replace)" />
                    <xsl:with-param name="replace" select="$replace" />
                    <xsl:with-param name="by" select="$by" />
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$text" />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:param name="base_db_export_path" />
    <xsl:variable name="language" select="item/language/isocode"/>
    <xsl:variable name="formatUri" select="concat(item/uristandard,'/',item/uriname,'.',$language,'.')" />
    <xsl:variable name="languagefile" select="document(concat('../gui-languages/',$language,'.xml'))" />
    <xsl:variable name='newline'>&lt;br/&gt;</xsl:variable>
    
    <!--Stylesheet-->
    <xsl:template match="/">
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>
        <html>
            <xsl:attribute name="lang">
                <xsl:value-of select="$language" />
            </xsl:attribute>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
                <title>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='document']"/>
                    <xsl:text>-</xsl:text>
                    <xsl:value-of select="label"/>
                </title>
                <xsl:call-template name="res">
                    <xsl:with-param name="base_res_uri" select="item/register/registry/uri"/>
                    <xsl:with-param name="base_language" select="$language"/>
                </xsl:call-template>
                <xsl:call-template name="linkalternate">
                    <xsl:with-param name="base_format_uri" select="$formatUri"/>
                    <xsl:with-param name="base_language" select="$language"/>
                    <xsl:with-param name="base_title" select="item/label"/>
                </xsl:call-template>
            </head>
            
            <body>
                <header>
                    <div id="topright">
                        <xsl:call-template name="top_right"/>
                    </div>
                    <div id="breadctxt">
                        <a href="http://ec.europa.eu/index_en.htm">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='ec']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a href="http://inspire.ec.europa.eu/">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='inspire']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a>
                            <xsl:attribute name="href" >
                                <xsl:value-of select="item/register/registry/uri"/>
                            </xsl:attribute>    
                            <xsl:value-of select="item/register/registry/label"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a>
                            <xsl:attribute name="href" >
                                <xsl:value-of select="item/register/uri"/>
                            </xsl:attribute>
                            <xsl:value-of select="item/register/label"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <span>
                            <xsl:value-of select="item/label" />
                        </span>
                    </div>
                </header>
                
                <article class="exp">
                    <xsl:apply-templates select="item"/>
                </article>
                
                <footer>
                    <xsl:call-template name="footer">
                        <xsl:with-param name="base_res_uri" select="item/register/registry/uri"/>
                    </xsl:call-template>
                </footer>
                
                <xsl:call-template name="dxbox"/>
                
            </body>
        </html>
    </xsl:template>
    
    <xsl:template match="item">
        
        <h2>  
            <xsl:value-of select="label" />
        </h2>

        <!-- Id and Version -->
        <p>
            <span class="csm">
                <xsl:value-of select="$languagefile/guilanguage/item[@key='id']"/>:</span>  
        </p>
        <div class="dcsm">
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uri"/>       
                </xsl:attribute>    
                <xsl:value-of select="uri"/>
            </a>
        </div>
        
        <xsl:if test="thisversion != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='this-version']"/>:
                </span> 
            </p>
            <div class="dcsm">
                <a>
                    <xsl:attribute name="href">
                        <xsl:value-of select="thisversion/uri"/>       
                    </xsl:attribute>    
                    <xsl:value-of select="thisversion/uri"/>
                </a>
            </div>
        </xsl:if>
        
        <xsl:if test="latestversion != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='latest-version']"/>:
                </span> 
            </p>
            <div class="dcsm">
                <a>
                    <xsl:attribute name="href">
                        <xsl:value-of select="latestversion/uri"/>       
                    </xsl:attribute>    
                    <xsl:value-of select="latestversion/uri"/>
                </a>
            </div>
        </xsl:if>
        
        <xsl:if test="previousversions != ''">
            <p>
                <xsl:choose>
                    <xsl:when test="count(//previousversions/version) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='previous-version']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="previousversions/version/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="previousversions/version/uri"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='previous-versions']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="previousversions/version">
                                    <li>  
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="uri"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>
        
        <br/>
        
        <!-- Label, Definition, Description -->
        <xsl:if test="label != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>:
                    <xsl:choose>
                        <xsl:when test="$language != label/@language">
                            <xsl:variable name="notavailable" select="$languagefile/guilanguage/item[@key='not-available-in']"/>   
                            <br/>
                            <span class="sml">
                                <xsl:text>[</xsl:text> 
                                <xsl:value-of select="$notavailable" disable-output-escaping="yes"/>
                                <xsl:text>]</xsl:text>
                            </span>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                </span> 
                <strong>
                    <xsl:value-of select="label" />
                </strong>
            </p>
        </xsl:if>
        
        <xsl:if test="definition != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='definition']"/>:
                    <xsl:choose>
                        <xsl:when test="$language != definition/@language">
                            <xsl:variable name="notavailable" select="$languagefile/guilanguage/item[@key='not-available-in']"/>   
                            <br/>
                            <span class="sml">
                                <xsl:text>[</xsl:text> 
                                <xsl:value-of select="$notavailable" disable-output-escaping="yes"/>
                                <xsl:text>]</xsl:text>
                            </span>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                </span>
            </p>    
            <div class="dcsm">
                <xsl:variable name="tmp" select="definition"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>            
            <div class="clft"></div>
        </xsl:if>
        
        <xsl:if test="description != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='description']"/>:
                    <xsl:choose>
                        <xsl:when test="$language != description/@language">
                            <xsl:variable name="notavailable" select="$languagefile/guilanguage/item[@key='not-available-in']"/>   
                            <br/>
                            <span class="sml">
                                <xsl:text>[</xsl:text> 
                                <xsl:value-of select="$notavailable" disable-output-escaping="yes"/>
                                <xsl:text>]</xsl:text>
                            </span>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                </span>
            </p>     
            <div class="dcsm">
                <xsl:variable name="tmp" select="description"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>     
            <div class="clft"></div>
        </xsl:if>        
        <br/>
        
        <!-- External References -->
        <xsl:variable name="externalReferenceGovernanceBody" select="customattributes/customattribute[name/text()='ExternalReferenceGovernanceBody']/values/value/uriname"></xsl:variable>
        <xsl:variable name="externalReferenceAvailableLanguages" select="customattributes/customattribute[name/text()='ExternalReferenceAvailableLanguages']/values/value/uriname"></xsl:variable>
        <xsl:variable name="externalReferenceLink" select="customattributes/customattribute[name/text()='ExternalReferenceLink']/values/value/uriname"></xsl:variable>
        <p>
            <span class="csm">
                <xsl:value-of select="$languagefile/guilanguage/item[@key='externalReferenceGovernanceBody']"/>:</span>
        </p>     
        <div class="dcsm">
            <xsl:value-of select="$externalReferenceGovernanceBody"/>
        </div>
        <div class="clft"></div>
        
        <p>
            <span class="csm">
                <xsl:value-of select="$languagefile/guilanguage/item[@key='externalReferenceAvailableLanguages']"/>:</span>     
        </p>
        <div class="dcsm">
            <xsl:value-of select="$externalReferenceAvailableLanguages"/>
        </div>
        <div class="clft"></div>
        
        <p>
            <span class="csm">
                <xsl:value-of select="$languagefile/guilanguage/item[@key='externalReferenceLink']"/>:</span>  
        </p>    
        <div class="dcsm">
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$externalReferenceLink"/>       
                </xsl:attribute>    
                <xsl:attribute name="target">_blank</xsl:attribute>
                <xsl:value-of select="$externalReferenceLink"/>
            </a>
        </div>
        <div class="clft"></div>
        <br/>
        
       
        <xsl:variable name="registry_uri" select="register/registry/uri"></xsl:variable>
        
        <!-- Governance Level, Status -->
        <xsl:if test="customattributes/customattribute[name/text()='GovernanceLevel'] != ''">
       
            <xsl:if test="//customattribute[name/text()='GovernanceLevel']/values != ''">
                <xsl:choose>
                    <xsl:when test="count(//customattribute[name/text()='GovernanceLevel']/values/value) = 1">
                                    
                        <p>
                            <span>
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='governance-level-label']"/>:
                            </span>
                        </p>
                        <xsl:variable name="governance_uriname" select="//customattribute[name/text()='GovernanceLevel']/values/value/uriname"></xsl:variable>
                        <xsl:variable name="governance_url" select="concat($registry_uri,'/governance-level/', $governance_uriname)"/>
                        <xsl:variable name="governance_label" select="concat($governance_uriname,'-label')"/>
                                    
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="$governance_url"/>
                                </xsl:attribute>    
                                <xsl:value-of select="$languagefile/guilanguage/item[@key=$governance_label]"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span>
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='governance-level-label']"/>:
                            </span>
                        </p>
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="//customattribute[name/text()='GovernanceLevel']/values/value">

                                    <xsl:variable name="governance_uriname" select="uriname"></xsl:variable>
                                    <xsl:variable name="governance_url" select="concat($registry_uri,'/governance-level/', $governance_uriname)"/>
                                    <xsl:variable name="governance_label" select="concat($governance_uriname,'-label')"/>
                                                
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="$governance_url"/>
                                            </xsl:attribute>    
                                            <xsl:value-of select="$languagefile/guilanguage/item[@key=$governance_label]"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:if>
        </xsl:if>
        
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='status']"/>:</span>
            <xsl:variable name="status_uri" select="status/uri"/>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="status/baseuri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="status/uriname"/>
                </xsl:attribute>    
                <xsl:value-of select="status/label"/>
            </a>
        </p>
        <br/>
        
        <!-- Predecessor, Successor -->
        <xsl:if test="predecessors != ''">
            <p>
                <xsl:choose>
                    <xsl:when test="count(//predecessors/predecessor) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='predecessor']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="predecessors/predecessor/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="predecessors/predecessor/label"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='predecessors']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="predecessors/predecessor">
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>
        
        <xsl:if test="successors != ''">
            <p>
                <xsl:choose>
                    <xsl:when test="count(//successors/successor) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='successor']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="successors/successor/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="successors/successor/label"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='successors']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="successors/successor">
                                    <li>  
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="label"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>
        
        <xsl:if test="predecessors != '' or successors != ''">
            <br/>
        </xsl:if>
        
        <!--Other formats-->
        
        <xsl:variable name="downloadFormat" select="$languagefile/guilanguage/item[@key='download-format']"/>
        <p>
            <xsl:variable name="myVarXML">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'XML'" />
                </xsl:call-template>
            </xsl:variable>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='other-formats']"/>:</span>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>xml</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt xml</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'XML'"/>
                <span>(Re3gistry)</span>
            </a>
            <xsl:variable name="myVarISO">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'ISO 19135 XML'" />
                </xsl:call-template>
            </xsl:variable>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>iso19135xml</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt iso</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'XML'"/>
                <sup>beta</sup>
                <span>(ISO 19135)</span>
            </a>
            <xsl:variable name="myVarRDF">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'RDF/XML'" />
                </xsl:call-template>
            </xsl:variable>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>rdf</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt rdf</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'RDF/XML'"/>
                <sup>beta</sup>
            </a>
            <xsl:variable name="myVarJSON">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'JSON'" />
                </xsl:call-template>
            </xsl:variable>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>json</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt json</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'JSON'"/>
            </a>
            <xsl:variable name="myVarATOM">
                <xsl:call-template name="string-replace-all">
                    <xsl:with-param name="text" select="$downloadFormat" />
                    <xsl:with-param name="replace" select="'{format_name}'" />
                    <xsl:with-param name="by" select="'ATOM'" />
                </xsl:call-template>
            </xsl:variable>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="$formatUri"/>
                    <xsl:text>atom</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt atom</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'Atom'"/>
            </a>
        </p>
       
    </xsl:template>
</xsl:stylesheet>