<?xml version="1.0" encoding="UTF-8"?>
<!--  Copyright 2010,2015 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 30/03/2015
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-dev@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    
    <xsl:include href="../res.xsl" />
    
    <xsl:output method="html"/>
    
    <xsl:variable name="languagefile" select="document(concat('../../gui-languages/',$language,'.xml'))" />
    <xsl:variable name="language" select="guilanguage/@languagecode"/>
    
    <xsl:param name="baseuri" />
    <xsl:param name="registryUriname" />
    <xsl:variable name="registryUri" select="concat($baseuri,'/',$registryUriname)" />
    
    <xsl:template match="/">  
        
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>
        <html>
            <xsl:attribute name="lang">
                <xsl:value-of select="$language" />
            </xsl:attribute>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
                <title>
                    <xsl:value-of select="guilanguage/item[@key='inspire-registry']" />
                </title>
                <xsl:call-template name="resmin">
                    <xsl:with-param name="base_res_uri" select="$registryUri"/>
                    <xsl:with-param name="base_language" select="$language"/>
                </xsl:call-template>
            </head>
            <body>
                <div id="about-dialog" title="INSPIRE registry">                  
                    
                    <h2>
                        <xsl:value-of select="guilanguage/item[@key='about']" /> - <xsl:value-of select="guilanguage/item[@key='inspire-registry']" />
                    </h2>
                    <p>
                        <xsl:value-of select="guilanguage/item[@key='about-the-data']" />
                    </p>
                    <br/>
                    <p>
                        <xsl:value-of select="guilanguage/item[@key='about-currently']" />:</p>
                    <ul>
                        <li>
                            <xsl:value-of select="guilanguage/item[@key='inspire-theme-register']" />: <xsl:value-of select="guilanguage/item[@key='about-theme-register-description']" />
                        </li>
                        <li>
                            <xsl:value-of select="guilanguage/item[@key='inspire-application-schema-register']" />: <xsl:value-of select="guilanguage/item[@key='about-pplication-schema-register-description']" />
                        </li>
                        <li>
                            <xsl:value-of select="guilanguage/item[@key='inspire-code-list-register']" />: <xsl:value-of select="guilanguage/item[@key='about-code-list-register-description']" />
                        </li>
                        <li>
                            <xsl:value-of select="guilanguage/item[@key='inspire-metadata-codelist']" />: <xsl:value-of select="guilanguage/item[@key='about-metadata-register-description']" />
                        </li>
                        <li>
                            <xsl:value-of select="guilanguage/item[@key='inspire-document-register']" />: <xsl:value-of select="guilanguage/item[@key='about-document-register-description']" />
                        </li>
                        <li>
                            <xsl:value-of select="guilanguage/item[@key='inspire-featureconcept-register']" />: <xsl:value-of select="guilanguage/item[@key='about-featureconcept-register-description']" />
                        </li>
                        <li>
                            <xsl:value-of select="guilanguage/item[@key='inspire-glossary-register']" />: <xsl:value-of select="guilanguage/item[@key='about-glossary-register-description']" />
                        </li>
                    </ul>
                    <br/>

                    <h3>Acknowledgements</h3>
                    <p>The INSPIRE registry is based on the Re3gistry software, which is being developed by the Are3NA project as part of the Interoperability Solutions for European Public Administrations (ISA) Programme [2] . ARe3NA  aims at establishing a Reusable INSPIRE Reference Platform, which is identifying and developing common components for the successful implementation of the INSPIRE Directive. To further address these interoperability issues and provide support to the Member States, the platform will provide guidance, collaboration, sharing of best practices and approaches and a reference implementation of common components.</p>
                
                    <h3>Accessing the INSPIRE Regisrty</h3>
                    <p>For more technical informations related to the access to the INSPIRE Registry, please visit the <a id="ah" href="#">help section</a>.</p>
                    <script>
                        $("#ah").click(function(){
                            $("#aboutd").dialog("close");
                            $("#helpd").dialog("open");
                        });                        
                    </script>
                    
                </div>
            </body>
        </html>
        
    </xsl:template>
</xsl:stylesheet>
