<!--  Copyright 2010,2015 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 30/03/2015
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-dev@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xs="http://www.w3.org/2001/XMLSchema"> 
    
    <!--Output settings-->
    <xsl:output method="text" encoding="UTF-8" media-type="text/plain" omit-xml-declaration="yes"/>

    <!--Variables & parameters declaration-->
    <xsl:param name="base_db_export_path" />
    
    <xsl:template match="/">
        {
        "glossary":{
        <xsl:apply-templates select="item"/>
        }
        }
    </xsl:template>
    
    <xsl:template match="item">
        
        "id":"<xsl:value-of select="uri"/>"
        <xsl:if test="thisversion != ''">
            ,
            "thisversion":"<xsl:value-of select="thisversion/uri" />"
        </xsl:if>
        <xsl:if test="latestversion != ''">
            ,
            "latestversion":"<xsl:value-of select="latestversion/uri" />"
        </xsl:if>
        <xsl:choose>
            <xsl:when test="previousversions">
                ,
                "historyversion":[
                <xsl:for-each select="previousversions/version">   
                    {
                    "version":"<xsl:value-of select="uri"/>"
                    }                
                    <xsl:choose>
                        <xsl:when test="following-sibling::version">
                            , 
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
                ]
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:variable name="language" select="language/isocode"></xsl:variable>   
        ,"language":"<xsl:value-of select="$language"/>",
        <xsl:if test="label != ''">
            "label":{
            "lang":"<xsl:value-of select="label/@language"/>",
            "text":"<xsl:value-of select="label" />"
            },
        </xsl:if>   
        <xsl:if test="definition != ''">
            <xsl:variable name="tmp" select="definition"/>
            <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
            "definition":{
            "lang":"<xsl:value-of select="definition/@language"/>",
            "text":"<xsl:value-of select="$newtext" />"
            },
        </xsl:if>
        <xsl:if test="description != ''">
            <xsl:variable name="tmp" select="description"/>
            <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
            "description":{
            "lang":"<xsl:value-of select="description/@language"/>",
            "text":"<xsl:value-of select="$newtext" />"
            },
        </xsl:if>
        <xsl:if test="customattributes/customattribute[name/text()='GovernanceLevel'] != ''">            
            <xsl:if test="customattributes/customattribute[name/text()='GovernanceLevel']/values != ''">            
                <xsl:for-each select="customattributes/customattribute[name/text()='GovernanceLevel']/values/value">                   
                    <xsl:variable name="governance_uriname" select="uriname"/>
                    <xsl:variable name="governance_url" select="concat(register/registry/uri,'/governance-level/', $governance_uriname)"/>
                    <xsl:if test="$governance_uriname != ''">                    
                        ,"governance-level":{
                        <xsl:variable name="governance_uriname" select="customattributes/customattribute[name/text()='GovernanceLevel']/values/value/uriname"></xsl:variable>
                        <xsl:variable name="governanceLabelLanguage" select="customattributes/customattribute[name/text()='GovernanceLevel']/label/@language"></xsl:variable>
                        <xsl:variable name="governance_url" select="concat(register/registry/uri,'/governance-level/', $governance_uriname)"/>
                        "id":"<xsl:value-of select="$governance_url" />",
                        "label":{
                        "lang":"<xsl:value-of select="$governanceLabelLanguage"/>",
                        "text":"<xsl:value-of select="$governance_uriname"/>"
                        }
                        } 
                    </xsl:if>              
                </xsl:for-each>
            </xsl:if>
        </xsl:if>  
        "itemclass":{
        "id":" <xsl:value-of select="itemclass/uriname"/>",
        "label":{
        "lang":"<xsl:value-of select="itemclass/label/@language"/>",
        "text":"<xsl:value-of select="itemclass/label" />"
        }
        }
        ,"status":{
        "id":" <xsl:value-of select="status/baseuri"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="status/uriname"/>",
        "label":{
        "lang":"<xsl:value-of select="status/label/@language"/>",
        "text":"<xsl:value-of select="status/label" />"
        }
        },
        "register":{
        "id":"<xsl:value-of select="register/uri"/>",
        "label":{
        "lang":"<xsl:value-of select="register/label/@language"/>",
        "text":"<xsl:value-of select="register/label"/>"
        },
        "registry":{
        "id":"<xsl:value-of select="register/registry/uri"/>",
        "label":{
        "lang":"<xsl:value-of select="register/registry/label/@language"/>",
        "text":"<xsl:value-of select="register/registry/label"/>"
        }
        }
        },
        "source":{
        <xsl:variable name="sourceDefinition" select="customattributes/customattribute[name/text()='SourceDefinition']/values/value/uriname"></xsl:variable>
        <xsl:variable name="sourceDescription" select="customattributes/customattribute[name/text()='SourceDescription']/values/value/uriname"></xsl:variable>
        "definition":"<xsl:value-of select="$sourceDefinition" />",
        "description":"<xsl:value-of select="$sourceDescription" />"
        }
        <xsl:choose>
            <xsl:when test="predecessors">
                ,
                "predecessors":[
                <xsl:for-each select="predecessors/predecessor">   
                    {
                    "predecessor":{
                    "id":"<xsl:value-of select="uri"/>",
                    "label":{
                    "lang":"<xsl:value-of select="label/@language"/>",
                    "text":"<xsl:value-of select="label" />"
                    }
                    }
                    }                
                    <xsl:choose>
                        <xsl:when test="following-sibling::predecessor">
                            , 
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
                ]
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
                    
        <xsl:choose>
            <xsl:when test="successors">
                ,
                "successors":[
                <xsl:for-each select="successors/successor">   
                    {
                    "successor":{
                    "id":"<xsl:value-of select="uri"/>",
                    "label":{
                    "lang":"<xsl:value-of select="label/@language"/>",
                    "text":"<xsl:value-of select="label" />"
                    }
                    }
                    }                
                    <xsl:choose>
                        <xsl:when test="following-sibling::successor">
                            , 
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
                ]
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>  
    </xsl:template>
</xsl:stylesheet>