/*
 * Copyright 2010,2015 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 30/03/2015
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrycommon.model;

import eu.europa.ec.re3gistrycommon.utils.StringUtils;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlRootElement;

@Entity
@Table(name = "localization")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Localization.findAll", query = "SELECT l FROM Localization l"),
    @NamedQuery(name = "Localization.findByUuid", query = "SELECT l FROM Localization l WHERE l.uuid = :uuid"),
    @NamedQuery(name = "Localization.findByLabel", query = "SELECT l FROM Localization l WHERE l.label = :label"),
    @NamedQuery(name = "Localization.findByDefinition", query = "SELECT l FROM Localization l WHERE l.definition = :definition"),
    @NamedQuery(name = "Localization.findByDescription", query = "SELECT l FROM Localization l WHERE l.description = :description"),
    @NamedQuery(name = "Localization.findByDatecreation", query = "SELECT l FROM Localization l WHERE l.datecreation = :datecreation"),
    @NamedQuery(name = "Localization.findByDatelastupdate", query = "SELECT l FROM Localization l WHERE l.datelastupdate = :datelastupdate"),
    /**
     * * custom query*
     */
    @NamedQuery(name = "Localization.findLocalizationByItem", query = "SELECT l FROM Localization l WHERE l.item = :item"),
    @NamedQuery(name = "Localization.findByRegistry", query = "SELECT l FROM Localization l WHERE l.registry = :registry"),
    @NamedQuery(name = "Localization.findByRegister", query = "SELECT l FROM Localization l WHERE l.register = :register"),
    @NamedQuery(name = "Localization.findLocalizationByRegister", query = "SELECT l FROM Localization l WHERE l.register = :register"),
    @NamedQuery(name = "Localization.findByItemAndAfterDate", query = "SELECT l FROM Localization l WHERE l.item = :item AND (l.datelastupdate >= :date OR (l.datelastupdate = null AND l.datecreation >= :date))"),
    @NamedQuery(name = "Localization.findByRegistryAndAfterDate", query = "SELECT l FROM Localization l WHERE l.registry = :registry AND (l.datelastupdate >= :date OR (l.datelastupdate = null AND l.datecreation >= :date))"),
    @NamedQuery(name = "Localization.findByRegisterAndAfterDate", query = "SELECT l FROM Localization l WHERE l.register = :register AND (l.datelastupdate >= :date OR (l.datelastupdate = null AND l.datecreation >= :date))"),
    @NamedQuery(name = "Localization.findByLanguagecodeAndStatus", query = "SELECT l FROM Localization l WHERE l.status = :status AND l.language = :language"),
    @NamedQuery(name = "Localization.findByItemclassAndLanguagecode", query = "SELECT l FROM Localization l WHERE l.itemclass = :itemclass AND l.language = :language"),
    @NamedQuery(name = "Localization.findByItemAndLanguagecode", query = "SELECT l FROM Localization l WHERE l.item = :item AND l.language = :language"),
    @NamedQuery(name = "Localization.findByCustomattributevalueAndLanguagecode", query = "SELECT l FROM Localization l WHERE l.customattributevalue = :customattributevalue AND l.language = :language"),
    @NamedQuery(name = "Localization.findByRegisterAndLanguagecode", query = "SELECT l FROM Localization l WHERE l.register = :register AND l.language = :language"),
    @NamedQuery(name = "Localization.findByRegistryAndLanguagecode", query = "SELECT l FROM Localization l WHERE l.registry = :registry AND l.language = :language"),
    @NamedQuery(name = "Localization.findByReferenceAndLanguagecode", query = "SELECT l FROM Localization l WHERE l.reference = :reference AND l.language = :language"),
    @NamedQuery(name = "Localization.findByItem", query = "SELECT l FROM Localization l WHERE l.item = :item"),
    @NamedQuery(name = "Localization.findByCustomattributevalue", query = "SELECT l FROM Localization l WHERE l.customattributevalue = :customattributevalue")
})
public class Localization implements Serializable {

    private static final long serialVersionUID = 1L;
    @Id
    @Basic(optional = false)
    @Column(name = "uuid")
    private String uuid;
    @Basic(optional = false)
    @Column(name = "label")
    private String label;
    @Column(name = "definition")
    private String definition;
    @Column(name = "description")
    private String description;
    @Column(name = "uri")
    private String uri;
    @Basic(optional = false)
    @Column(name = "datecreation")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datecreation;
    @Column(name = "datelastupdate")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datelastupdate;
    @JoinColumn(name = "status", referencedColumnName = "uuid")
    @ManyToOne
    private Status status;
    @JoinColumn(name = "registry", referencedColumnName = "uuid")
    @ManyToOne
    private Registry registry;
    @JoinColumn(name = "register", referencedColumnName = "uuid")
    @ManyToOne
    private Register register;
    @JoinColumn(name = "language", referencedColumnName = "uuid")
    @ManyToOne(optional = false)
    private Languagecode language;
    @JoinColumn(name = "itemclass", referencedColumnName = "uuid")
    @ManyToOne
    private Itemclass itemclass;
    @JoinColumn(name = "item", referencedColumnName = "uuid")
    @ManyToOne
    private Item item;
    @JoinColumn(name = "customattributevalue", referencedColumnName = "uuid")
    @ManyToOne
    private Customattributevalue customattributevalue;
    @JoinColumn(name = "reference", referencedColumnName = "uuid")
    @ManyToOne
    private Reference reference;

    public Localization() {
    }

    public Localization(String uuid) {
        this.uuid = uuid;
    }

    public Localization(String uuid, String label, Date datecreation) {
        this.uuid = uuid;
        this.label = label;
        this.datecreation = datecreation;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getLabel() {
        if (label != null && (label.length() <= 0 || label.trim().length() <= 0)) {
            label = null;
        }
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public String getDefinition() {
        return definition;
    }

    public void setDefinition(String definition) {

        if (definition != null && (definition.length() <= 0 || definition.trim().length() <= 0)) {
            definition = null;
        }

        this.definition = definition;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {

        if (description != null && (description.length() <= 0 || description.trim().length() <= 0)) {
            description = null;
        }

        this.description = description;
    }

    public Date getDatecreation() {
        return datecreation;
    }

    public void setDatecreation(Date datecreation) {
        this.datecreation = datecreation;
    }

    public Date getDatelastupdate() {
        return datelastupdate;
    }

    public void setDatelastupdate(Date datelastupdate) {
        this.datelastupdate = datelastupdate;
    }

    public Status getStatus() {
        return status;
    }

    public void setStatus(Status status) {
        this.status = status;
    }

    public Registry getRegistry() {
        return registry;
    }

    public void setRegistry(Registry registry) {
        this.registry = registry;
    }

    public Register getRegister() {
        return register;
    }

    public void setRegister(Register register) {
        this.register = register;
    }

    public Languagecode getLanguage() {
        return language;
    }

    public void setLanguage(Languagecode language) {
        this.language = language;
    }

    public Itemclass getItemclass() {
        return itemclass;
    }

    public void setItemclass(Itemclass itemclass) {
        this.itemclass = itemclass;
    }

    public Item getItem() {
        return item;
    }

    public void setItem(Item item) {
        this.item = item;
    }

    public Customattributevalue getCustomattributevalue() {
        return customattributevalue;
    }

    public void setCustomattributevalue(Customattributevalue customattributevalue) {
        this.customattributevalue = customattributevalue;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (uuid != null ? uuid.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Localization)) {
            return false;
        }
        Localization other = (Localization) object;
        return (this.uuid != null || other.uuid == null) && (this.uuid == null || this.uuid.equals(other.uuid));
    }

    @Override
    public String toString() {
        return "eu.europa.ec.re3gistrycommon.model.Localization[ uuid=" + uuid + " ]";
    }

    /**
     * Creates the uuid for the Localization's objects
     *
     * @param itemUuid The item's uuid
     * @param languageIsoCode The language's iso code
     * @return the uuid
     * @throws Exception
     */
    public static String createUuid(String itemUuid, String languageIsoCode) throws Exception {
        return StringUtils.createUUID(itemUuid + languageIsoCode, Localization.class);
    }

    public Reference getReference() {
        return reference;
    }

    public void setReference(Reference reference) {
        this.reference = reference;
    }

    public String getUri() {
        return uri;
    }

    public void setUri(String uri) {
        this.uri = uri;
    }

}
