/*
 * Copyright 2010,2015 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 30/03/2015
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrydata.servlet;

import eu.europa.ec.re3gistrycommon.managers.DataprocedureMgr;
import eu.europa.ec.re3gistrycommon.managers.ProcedurestatusMgr;
import eu.europa.ec.re3gistrycommon.model.Dataprocedure;
import eu.europa.ec.re3gistrycommon.model.Procedurestatus;
import eu.europa.ec.re3gistrycommon.model.Users;
import eu.europa.ec.re3gistrycommon.utils.Mail;
import eu.europa.ec.re3gistrycommon.utils.PersistenceFactory;
import eu.europa.ec.re3gistrydata.constants.Constants;
import eu.europa.ec.re3gistrydata.managers.DataMgr;
import eu.europa.ec.re3gistrydata.managers.PropertyMgr;
import eu.europa.ec.re3gistrydata.managers.ZipMgr;
import eu.europa.ec.re3gistrystaticizer.StaticizeFiles;
import java.io.File;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Properties;
import java.util.ResourceBundle;
import javax.persistence.EntityManager;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.apache.log4j.Logger;

public class ProcedureStart extends HttpServlet {

    private static final Logger log = Logger.getLogger(Constants.MODULE_NAME);

    private ResourceBundle localizationres;
    private EntityManager em;
    private DataprocedureMgr dataprocedureMgr;
    private Properties properties;
    private Users user;

    private String dataPath;
    private String procedureDescription;
    private boolean flagIgnoreWarning;

    /**
     * Processes requests for both HTTP <code>GET</code> and <code>POST</code>
     * methods.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    protected void startProcedure(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException, Exception {
        Dataprocedure dataprocedure = null;

        log.info("###");
        log.info("### STATRING DATA PROCEDURE ###");

        try {
            //Starting the data procedure andi initializing the dataprocedureMgr
            dataprocedure = this.initprocedure(request);

            //Checking if other procedure is running or there are previous unprocessed procedures
            if (dataprocedureMgr.isProcedureInProgress(this.em) || this.isUnprecessedProcedureAvailable()) {
                //Setting queue
                em.getTransaction().begin();
                dataprocedureMgr.updateDataProcedureStatus(em, dataprocedure, eu.europa.ec.re3gistrycommon.constants.Constants.ID_QUEUE_STATUS);
                em.getTransaction().commit();

                //Sending mail for queue
                Mail m = new Mail();
                String subject;
                subject = localizationres.getString("export.mail.subject.queue").replace("{procedureDescription}", (dataprocedure != null) ? dataprocedure.getComment() : "--");
                String body = localizationres.getString("export.mail.body.queue").replace("{user}", user.getEmail()).replace("{procedureDescription}", this.procedureDescription);
                m.sendbyMail(request, null, subject, body);

                log.info("## Data procedure queued");

            } else {

                try {
                    //Starting the data procedure
                    dataprocedure = this.startDataProcedure(request, dataprocedure);
                } catch (Exception e) {
                    log.error("A generic error has occurred. Detail: "+e.getMessage());
                    if (dataprocedure != null) {
                        em.getTransaction().begin();
                        dataprocedureMgr.updateDataProcedureStatus(em, dataprocedure, eu.europa.ec.re3gistrycommon.constants.Constants.ID_FAILED_STATUS);
                        em.getTransaction().commit();
                    }
                }

                //Process queue after the current procedure has finished 
                this.processQueue(request);
            }
        } catch (Exception e) {
            //In case of unaxpected error in the servlet, fill with current error and send email
            String genericError = "An error occurs while executing the operations. Error: " + e.getMessage();

            Mail m = new Mail();
            String subject = localizationres.getString("export.mail.subject.error").replace("{procedureDescription}", (dataprocedure != null) ? dataprocedure.getComment() : "--");
            String body = localizationres.getString("export.mail.body.genericerror").replace("{0}", Constants.ERROR_KEY_ANALYZER).replace("{user}", user.getEmail()).replace("{procedureDescription}", this.procedureDescription);
            body += "<br/>" + genericError;

            //Sending mail               
            m.sendbyMail(request, null, subject, body);

            //Setting the failed status for the current data procedure
            if (dataprocedure != null) {
                em.getTransaction().begin();
                dataprocedureMgr.updateDataProcedureStatus(em, dataprocedure, eu.europa.ec.re3gistrycommon.constants.Constants.ID_FAILED_STATUS);
                em.getTransaction().commit();
            }

            log.info("## This data procedure had some errors.");

            //Processing queue also in case the current procedure ends with errors
            this.processQueue(request);
        }

        log.info("### DATA PROCEDURE END ###");
        log.info("###");
    }

    /**
     * Handles the HTTP <code>GET</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        try {
            startProcedure(request, response);
        } catch (Exception ex) {
        }
    }

    /**
     * Handles the HTTP <code>POST</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        try {
            startProcedure(request, response);
        } catch (Exception ex) {
        }
    }

    /**
     * Returns a short description of the servlet.
     *
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }

    private Dataprocedure initprocedure(HttpServletRequest request) throws Exception {
        log.info("## Initializing the data procedure");

        //Localization settings
        HttpSession s = request.getSession();
        String currentLanguage = (String) s.getAttribute(Constants.LANGUAGE_SESSION_KEY);
        if (currentLanguage == null) {
            currentLanguage = request.getLocale().toString();
        }

        //Initializing variables
        this.properties = PropertyMgr.getProperties();
        this.localizationres = ResourceBundle.getBundle(Constants.LOCALIZATION_PREFIX + Constants.MODULE_NAME + Constants.LOCALIZATION_SUFFIX, new Locale(currentLanguage));
        this.em = PersistenceFactory.getEntityManagerFactory().createEntityManager();
        this.dataprocedureMgr = new DataprocedureMgr(em);
        this.user = (Users) request.getSession().getAttribute(eu.europa.ec.re3gistrycommon.constants.Constants.USER_KEY);

        //Preparing the input data file
        this.setDataPath(request);
        this.prepareData(request);

        //Cheching if there are unprocessed procedures
        Dataprocedure tmp;
        em.getTransaction().begin();
        tmp = dataprocedureMgr.storeDataProcedure(em, procedureDescription, eu.europa.ec.re3gistrycommon.constants.Constants.ID_LOADING_STATUS, user, dataPath, flagIgnoreWarning);
        em.getTransaction().commit();

        log.info("## Data procedure initialized");

        return tmp;
    }

    /**
     * Check if there is a custom temp folder. The temp folder is used to
     * temporary store the unzipped file. These file are deleted after the
     * procedure end.
     */
    private void setDataPath(HttpServletRequest request) {
        log.info("## Setting up the temp data path for this procedure");

        //Getting the standard data folder
        this.dataPath = request.getSession().getServletContext().getRealPath(Constants.DEFAULT_TEMP_FOLDER_NAME);

        //Checking if the data folder is customized
        String customDataFolder = properties.getProperty(Constants.KEY_CUSTOM_TEMP_FOLDER);
        if (customDataFolder != null && customDataFolder.length() > 0) {
            log.info("## Custom temp data folder found: " + customDataFolder);
            this.dataPath = customDataFolder + File.separator + String.valueOf(System.currentTimeMillis());
        } else {
            this.dataPath += File.separator + String.valueOf(System.currentTimeMillis());
        }

        //Creating folder if it does not exist
        File f = new File(this.dataPath);
        if (!f.exists()) {
            f.mkdirs();
        }
    }

    /**
     * Reading data file and parameters from the request and unzipping the input
     * file
     */
    private void prepareData(HttpServletRequest request) throws Exception {
        log.info("## Preparing data");

        List<FileItem> fl = new ServletFileUpload(new DiskFileItemFactory()).parseRequest(request);
        FileItem dataFile = null;

        //Getting parameter from the request
        for (FileItem item : fl) {
            if (!item.isFormField()) {
                dataFile = item;
            } else {
                if (item.getFieldName().equals(Constants.FORM_FIELD_COMMENT)) {
                    this.procedureDescription = item.getString();
                }
                if (item.getFieldName().equals(Constants.FORM_FIELD_FWARNINGS)) {
                    this.flagIgnoreWarning = (item.getString() != null && item.getString().equals(Constants.CHECKBOX_ON_VALUE));
                }
            }
        }

        if (dataFile == null || dataFile.getSize() == 0) {
            throw new Exception(this.localizationres.getString("error.datamgr.unzip.importfile"));
        }

        //Storing the zip file
        File file = new File(this.dataPath + Constants.ZIP_FILE_EXTENSION);
        if (!file.exists()) {
            file.createNewFile();
        }
        dataFile.write(file);

        log.info("## Unzipping data file ...");
        if (!ZipMgr.unzipFile(this.dataPath, file)) {
            throw new Exception(this.localizationres.getString("error.datamgr.unzip.unziperror"));
        }
        log.info("## File succesfully unzipped.");
    }

    private Dataprocedure startDataProcedure(HttpServletRequest request, Dataprocedure indataprocedure) throws Exception {
        log.info("## Starting data procedure");

        DataMgr dataMgr = new DataMgr(request, localizationres, indataprocedure);

        //Starting DB data procedure
        Dataprocedure dataprocedure = dataMgr.startProcedure(indataprocedure);

        //Statring the staticizer
        StaticizeFiles staticizeFile = new StaticizeFiles(request, dataprocedure);
        staticizeFile.startToStaticizeFiles(dataprocedure);

        //Sending mail in case of success
        //In case of warnings
        if (dataMgr.getReportMgr().getReports().size() > 0) {
            //Sending mail in case of data store error
            Mail m = new Mail();
            String subject = localizationres.getString("export.mail.subject.warning").replace("{procedureDescription}", (dataprocedure != null) ? dataprocedure.getComment() : "--");
            String body = localizationres.getString("export.mail.body.warning").replace("{0}", Constants.ERROR_KEY_STORE).replace("{user}", user.getEmail()).replace("{procedureDescription}", this.procedureDescription);

            //Creating attachment                
            File tempFile = dataMgr.createAttachmentFile();
            m.sendbyMail(request, tempFile, subject, body);

        } else {
            Mail m = new Mail();
            String subject = localizationres.getString("export.mail.subject.ok").replace("{procedureDescription}", (dataprocedure != null) ? dataprocedure.getComment() : "--");
            String body = localizationres.getString("export.mail.body.success").replace("{user}", user.getEmail()).replace("{procedureDescription}", this.procedureDescription);
            m.sendbyMail(request, null, subject, body);
        }
        return dataprocedure;
    }

    private void processQueue(HttpServletRequest request) throws Exception {
        ProcedurestatusMgr procedurestatusMgr = new ProcedurestatusMgr(em);
        Procedurestatus procedureStatus = procedurestatusMgr.getStatusByUuid(eu.europa.ec.re3gistrycommon.constants.Constants.ID_QUEUE_STATUS);
        List<Dataprocedure> dataprocedures = dataprocedureMgr.findByProcedurestatus(procedureStatus);
        Iterator<Dataprocedure> it = dataprocedures.iterator();

        while (it.hasNext()) {
            log.info("## A process in queue is being launched");
            try {
                this.startDataProcedure(request, it.next());
            } catch (Exception e) {
            }
        }

        //Checking if other datprocedure has been added
        dataprocedures = dataprocedureMgr.findByProcedurestatus(procedureStatus);
        if (dataprocedures.size() > 0) {
            this.processQueue(request);
        }
    }

    private boolean isUnprecessedProcedureAvailable() throws Exception {
        ProcedurestatusMgr procedurestatusMgr = new ProcedurestatusMgr(em);
        Procedurestatus procedureStatus = procedurestatusMgr.getStatusByUuid(eu.europa.ec.re3gistrycommon.constants.Constants.ID_QUEUE_STATUS);
        List<Dataprocedure> queueddataprocedures = dataprocedureMgr.findByProcedurestatus(procedureStatus);

        if (!dataprocedureMgr.isProcedureInProgress(em) && queueddataprocedures.size() > 0) {
            log.info("## There are unprocessed procedure in queue. Launching it firstly.");
            return true;
        }

        return false;
    }
}
