/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package eu.europa.ec.re3gistrystaticizer;

import eu.europa.ec.re3gistrycommon.managers.ChangelogMgr;
import eu.europa.ec.re3gistrycommon.managers.DataprocedureMgr;
import eu.europa.ec.re3gistrycommon.managers.LanguagecodeMgr;
import eu.europa.ec.re3gistrycommon.model.Changelog;
import eu.europa.ec.re3gistrycommon.model.Dataprocedure;
import eu.europa.ec.re3gistrycommon.model.Item;
import eu.europa.ec.re3gistrycommon.model.Itemclass;
import eu.europa.ec.re3gistrycommon.model.Languagecode;
import eu.europa.ec.re3gistrycommon.model.Users;
import eu.europa.ec.re3gistrycommon.utils.Mail;
import eu.europa.ec.re3gistrycommon.utils.PersistenceFactory;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.filescreation.CreateSOLRFiles;
import eu.europa.ec.re3gistrystaticizer.filescreation.CreateStandardFiles;
import eu.europa.ec.re3gistrystaticizer.filescreation.CreateVARFiles;
import eu.europa.ec.re3gistrystaticizer.filescreation.CreateXSLCustomFiles;
import java.io.File;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Locale;
import java.util.Properties;
import java.util.ResourceBundle;
import javax.persistence.EntityManager;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

public class StaticizeFiles {

    private final EntityManager em;

    private final Dataprocedure dataprocedure;
    private final HttpServletRequest request;

    private String staticizerMainfolderName;
    private String staticizerXSLFolder;
    private ResourceBundle localizationres;
    private CreateStandardFiles createStandardFiles;

    private final String folderSeparator = System.getProperty("file.separator");

    private static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);

    public StaticizeFiles(HttpServletRequest request, Dataprocedure dataprocedure) throws Exception {
        this.request = request;
        this.dataprocedure = dataprocedure;

        this.em = PersistenceFactory.getEntityManagerFactory().createEntityManager();
    }

    public void startToStaticizeFiles(Dataprocedure dataprocedure) throws Exception {
        initPropertiesAndMainStaticizerFolder();
        startStaticization(dataprocedure);
    }

    private void initPropertiesAndMainStaticizerFolder() {
        /**
         * Initializing the system localization
         */
        HttpSession s = this.request.getSession();
        String currentLanguage = (String) s.getAttribute(Constants.LANGUAGE_SESSION_KEY);
        if (currentLanguage == null) {
            currentLanguage = this.request.getLocale().toString();
        }
        localizationres = ResourceBundle.getBundle(Constants.LOCALIZATION_PREFIX + Constants.MODULE_NAME + Constants.LOCALIZATION_SUFFIX, new Locale(currentLanguage));

        Properties properties = eu.europa.ec.re3gistrycommon.utils.Configuration.getInstance().getProperties(Constants.MODULE_NAME);
        log.info("Module properties loaded");

        /**
         * initialize the main staticizer folder
         */
        staticizerMainfolderName = properties.getProperty(Constants.STATICIZER_FOLDER_PATH, "E:/re3gistry-data/staticizer");
        new File(staticizerMainfolderName).mkdir();

        staticizerXSLFolder = properties.getProperty(Constants.STATICIZER_FORMATS_PATH, "E:/re3gistry-data/xsl");
    }

    private void startStaticization(Dataprocedure dataprocedure) throws Exception {
        DataprocedureMgr dataproceduteMgr = new DataprocedureMgr(em);
        Users user = (Users) request.getSession().getAttribute(eu.europa.ec.re3gistrycommon.constants.Constants.USER_KEY);

        try {
            setWritingFilesStatus(dataproceduteMgr);
            staticizeItems();
            setCompletedStatus(dataproceduteMgr, dataprocedure);

        } catch (Exception ex) {
            setFailedStatus(dataproceduteMgr, dataprocedure);

            log.error("StaticizeLastImportedItems setProcedurestatus " + ex.getMessage());

            Mail mail = new Mail();
            String subject = localizationres.getString("staticizer.mail.subject.error").replace("{procedureDescription}", dataprocedure.getComment());
            String body = localizationres.getString("staticizer.mail.body.failed").replace("{user}", user.getEmail()).replace("{procedureDescription}", dataprocedure.getComment());

            mail.sendbyMail(request, null, subject, body);
        }
    }

    private void setFailedStatus(DataprocedureMgr dataprocedureMgr, Dataprocedure dataprocedure) throws Exception {
        em.getTransaction().begin();
        dataprocedureMgr.updateDataProcedureStatus(em, dataprocedure, eu.europa.ec.re3gistrycommon.constants.Constants.ID_FAILED_STATUS);
        em.getTransaction().commit();
    }

    private void setCompletedStatus(DataprocedureMgr dataprocedureMgr, Dataprocedure dataprocedure) throws Exception {
        em.getTransaction().begin();
        dataprocedureMgr.updateDataProcedureStatus(em, dataprocedure, eu.europa.ec.re3gistrycommon.constants.Constants.ID_COMPLETED_STATUS);
        em.getTransaction().commit();
    }

    private void setWritingFilesStatus(DataprocedureMgr dataprocedureMgr) throws Exception {
        em.getTransaction().begin();
        dataprocedureMgr.updateDataProcedureStatus(em, dataprocedure, eu.europa.ec.re3gistrycommon.constants.Constants.ID_WRITING_FILES_STATUS);
        em.getTransaction().commit();
    }

    private void staticizeItems() throws Exception {
        ChangelogMgr changelogMgr = new ChangelogMgr(em);

        /**
         * get items to be staticize with dataprocedure
         */
        List<Changelog> changelogItems = changelogMgr.getChangelogByDataProcedure(dataprocedure);

        LanguagecodeMgr languagecodeMgr = new LanguagecodeMgr(em);
        List<Languagecode> allLanguagecode = languagecodeMgr.findAll();

        LinkedHashMap<Item, List<Languagecode>> itemsTostaticize = new LinkedHashMap<Item, List<Languagecode>>();
        LinkedHashMap<Itemclass, List<Languagecode>> registerToStaticize = new LinkedHashMap<Itemclass, List<Languagecode>>();

        for (Changelog changelog : changelogItems) {
            Item item = changelog.getItem();

            if (!itemsTostaticize.containsKey(item)) {
                if (item.getVersionnumber() == 0) {
                    itemsTostaticize.put(item, allLanguagecode);
                }
            }
            Itemclass itemclass = item.getItemclass();
            if (itemclass.getParent() == null) {
                if (!registerToStaticize.containsKey(itemclass)) {
                    registerToStaticize.put(itemclass, allLanguagecode);
                }
            }
        }

        /**
         * add to the list all the folder that are created
         */
        LinkedHashMap<File, String> linkedHashMapVAR = new LinkedHashMap();
        log.info("========================== Standard && Custom Files ==========================");
        createStandardFiles = new CreateStandardFiles(this, itemsTostaticize, linkedHashMapVAR, registerToStaticize, em);
        createStandardFiles.createFiles();
        log.info("==================================================================================================================");
        log.info("================ Custom XSL Files (about,extensibility,help,rss,search,searchresult,status,system) ===============");
        new CreateXSLCustomFiles(this, linkedHashMapVAR, em);
        log.info("==================================================================================================================");
        log.info("================================================ VAR Files =======================================================");
        new CreateVARFiles(linkedHashMapVAR, em);
        log.info("==================================================================================================================");
        log.info("================================================ SOLR Files ======================================================");
        new CreateSOLRFiles(this, itemsTostaticize, registerToStaticize, em);
        log.info("==================================================================================================================");

    }

    public String getFolderSeparator() {
        return folderSeparator;
    }

    public String getStaticizerMainfolderName() {
        return staticizerMainfolderName;
    }

    public String getStaticizerXSLFolder() {
        return staticizerXSLFolder;
    }

    public CreateStandardFiles getCreateStandardFiles() {
        return createStandardFiles;
    }

}
