/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package eu.europa.ec.re3gistrystaticizer.filescreation;

import eu.europa.ec.re3gistrycommon.managers.LanguagecodeMgr;
import eu.europa.ec.re3gistrycommon.managers.LocalizationMgr;
import eu.europa.ec.re3gistrycommon.model.Item;
import eu.europa.ec.re3gistrycommon.model.Itemclass;
import eu.europa.ec.re3gistrycommon.model.Languagecode;
import eu.europa.ec.re3gistrycommon.model.Localization;
import eu.europa.ec.re3gistrystaticizer.StaticizeFiles;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.marshaller.RegisterStaticizer;
import eu.europa.ec.re3gistrystaticizer.marshaller.RegistryStaticizer;
import eu.europa.ec.re3gistrystaticizer.marshaller.StaticizeLastImportedItems;
import java.io.File;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import javax.persistence.EntityManager;

/**
 *
 * @author epuread
 */
public class CreateStandardFiles {

    private String staticizerStandardFolder;
    private String staticizerCutomFolder;
    private String folderStandardStaticizer;
    private String folderCustomStaticizer;
    private String[] EXTENSIONS;
    private final String folderSeparator = System.getProperty("file.separator");
    private final StaticizeFiles staticizeFiles;
    private final LinkedHashMap<Item, List<Languagecode>> itemsTostaticize;
    private final LinkedHashMap<File, String> linkedHashMapVAR;
    private final EntityManager em;
    private final LinkedHashMap<Itemclass, List<Languagecode>> registerToStaticize;

    public CreateStandardFiles(StaticizeFiles staticizeFiles, LinkedHashMap<Item, List<Languagecode>> itemsTostaticize, LinkedHashMap<File, String> linkedHashMapVAR, LinkedHashMap<Itemclass, List<Languagecode>> registerToStaticize, EntityManager em) throws Exception {
        this.staticizeFiles = staticizeFiles;
        this.itemsTostaticize = itemsTostaticize;
        this.linkedHashMapVAR = linkedHashMapVAR;
        this.registerToStaticize = registerToStaticize;
        this.em = em;
    }

    public void createFiles() throws Exception {
        initalizateStaticizerStandardAndCustomFolders();

        if (EXTENSIONS.length != 0 && !EXTENSIONS[0].equals("")) {
            createStandardFiles(itemsTostaticize, linkedHashMapVAR, registerToStaticize, em);
        }
    }

    private void initalizateStaticizerStandardAndCustomFolders() {
        /**
         * initialize the staticizer standard and custom folder
         */
        Properties properties = eu.europa.ec.re3gistrycommon.utils.Configuration.getInstance().getProperties(Constants.MODULE_NAME);

        staticizerStandardFolder = properties.getProperty(Constants.STATICIZER_STANDARD_FOLDER, "standard");
        folderStandardStaticizer = staticizeFiles.getStaticizerMainfolderName() + folderSeparator + staticizerStandardFolder;
        new File(folderStandardStaticizer).mkdirs();

        staticizerCutomFolder = properties.getProperty(Constants.STATICIZER_CUSTOM_FOLDER, "custom");
        folderCustomStaticizer = staticizeFiles.getStaticizerMainfolderName() + folderSeparator + staticizerCutomFolder;
        new File(folderCustomStaticizer).mkdirs();

        String formatList = properties.getProperty(Constants.STATICIZER_FORMATS);
        EXTENSIONS = formatList.split(properties.getProperty(Constants.STATICIZER_FORMATS_SEPARATOR));
    }

    private StaticizeLastImportedItems createStandardFiles(LinkedHashMap<Item, List<Languagecode>> itemsTostaticize, LinkedHashMap<File, String> linkedHashMap, LinkedHashMap<Itemclass, List<Languagecode>> registerToStaticize, EntityManager em) throws Exception {
        /**
         * read/write the items
         */
        List<File> folderItemList = new ArrayList<File>();
        LocalizationMgr localizationMgr = new LocalizationMgr(em);
        LanguagecodeMgr languagecodeMgr = new LanguagecodeMgr(em);
        Languagecode masterLanguage = languagecodeMgr.getMasterLanguagecode();

        StaticizeLastImportedItems staticizeLastImportedItems = new StaticizeLastImportedItems(staticizeFiles, em);
        for (Map.Entry<Item, List<Languagecode>> entry : itemsTostaticize.entrySet()) {
            Item item = entry.getKey();
            List<Languagecode> list = entry.getValue();
            for (Languagecode languagecode : list) {
                Localization itemLocalization;
                try {
                    itemLocalization = localizationMgr.findByItemAndLanguagecode(item, languagecode);
                    if (itemLocalization != null) {
                        folderItemList.addAll(staticizeLastImportedItems.createItemFiles(item, itemLocalization, languagecode));
                    } else {
                        itemLocalization = localizationMgr.findByItemAndLanguagecode(item, masterLanguage);
                        folderItemList.addAll(staticizeLastImportedItems.createItemFiles(item, itemLocalization, languagecode));
                    }
                } catch (Exception ex) {
                    itemLocalization = localizationMgr.findByItemAndLanguagecode(item, masterLanguage);
                    folderItemList.addAll(staticizeLastImportedItems.createItemFiles(item, itemLocalization, languagecode));
                }
            }
        }

        /**
         * create the register
         */
        for (Map.Entry<Itemclass, List<Languagecode>> entry : registerToStaticize.entrySet()) {
            Itemclass itemclass = entry.getKey();
            List<Languagecode> list = entry.getValue();
            for (Languagecode languagecode : list) {
                RegisterStaticizer registerStaticizer = new RegisterStaticizer(staticizeFiles, em);
                folderItemList.add(registerStaticizer.addRegisterFiles(itemclass.getRegister(), languagecode));
            }
        }

        /**
         * create the registry
         */
        RegistryStaticizer registryStaticizer = new RegistryStaticizer(staticizeFiles, em);
        folderItemList.addAll(registryStaticizer.addRegistryFiles());

        for (File file : folderItemList) {
            if (!linkedHashMap.containsKey(file)) {
                linkedHashMap.put(file, "");
            }
        }

        return staticizeLastImportedItems;
    }

    public String getFolderCustomStaticizer() {
        return folderCustomStaticizer;
    }

    public String getFolderStandardStaticizer() {
        return folderStandardStaticizer;
    }

    public String[] getEXTENSIONS() {
        return EXTENSIONS;
    }

    public StaticizeFiles getStaticizeFiles() {
        return staticizeFiles;
    }

}
