/*
 * Copyright 2010,2015 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 30/03/2015
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.marshaller;

import eu.europa.ec.re3gistrycommon.managers.ItemMgr;
import eu.europa.ec.re3gistrycommon.managers.LanguagecodeMgr;
import eu.europa.ec.re3gistrycommon.managers.LocalizationMgr;
import eu.europa.ec.re3gistrycommon.model.Item;
import eu.europa.ec.re3gistrycommon.model.Languagecode;
import eu.europa.ec.re3gistrycommon.model.Localization;
import eu.europa.ec.re3gistrycommon.model.Reference;
import eu.europa.ec.re3gistrycommon.model.Register;
import eu.europa.ec.re3gistrycommon.model.Registry;
import eu.europa.ec.re3gistrycommon.utils.StringUtils;
import eu.europa.ec.re3gistrystaticizer.StaticizeFiles;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.ItemStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.RegisterStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DefinitionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DescriptionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.LabelAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.ReferenceAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.RegistryAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.RegisterItemStandardList;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.persistence.EntityManager;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.transform.Transformer;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import net.sf.saxon.TransformerFactoryImpl;

public class RegisterStaticizer {

    private final String folderSeparator;
    private final String folderStandardStaticizer;
    private final String folderCustomStaticizer;
    private final EntityManager em;
    private static org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);
    private final StaticizeFiles staticizeFiles;
    private final Languagecode masterLanguage;

    public RegisterStaticizer(StaticizeFiles staticizeFiles, EntityManager em) throws Exception {
        this.staticizeFiles = staticizeFiles;
        this.folderSeparator = staticizeFiles.getFolderSeparator();
        this.folderStandardStaticizer = staticizeFiles.getCreateStandardFiles().getFolderStandardStaticizer();
        this.folderCustomStaticizer = staticizeFiles.getCreateStandardFiles().getFolderCustomStaticizer();
        this.em = em;

        LanguagecodeMgr languagecodeMgr = new LanguagecodeMgr(em);
        masterLanguage = languagecodeMgr.getMasterLanguagecode();
    }

    public File addRegisterFiles(Register register, Languagecode languagecode) {
        if (staticizeFiles.getCreateStandardFiles().getEXTENSIONS().length != 0 && !staticizeFiles.getCreateStandardFiles().getEXTENSIONS()[0].equals("")) {
            try {
                LocalizationMgr localizationMgr = new LocalizationMgr(em);
                Localization registerLocalization = localizationMgr.findByRegisterAndLanguagecode(register, languagecode);
                if (registerLocalization == null) {
                    registerLocalization = localizationMgr.findByRegisterAndLanguagecode(register, masterLanguage);
                }
                RegisterStandard registerStandard = addRegisterStandard(register, registerLocalization);
                return createXMLRegisterFile(registerStandard, register);
            } catch (Exception ex) {
                Logger.getLogger(RegisterStaticizer.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
        return null;
    }

    public RegisterStandard addRegisterStandard(Register register, Localization registerLocalization) throws Exception {
        RegisterStandard registerStandard = new RegisterStandard();
        registerStandard.setUuid(register.getUuid());
        registerStandard.setBaseuri(register.getBaseuri());
        registerStandard.setUriname(register.getUriname());
        registerStandard.setUri(register.getBaseuri() + "/" + register.getUriname());
        registerStandard.setUristandard(register.getBaseuri() + "/" + register.getUriname());

        registerStandard.setDatecreation(register.getDatecreation());
        registerStandard.setDatelastupdate(register.getDatelastupdate());

        Languagecode registerLanguage = registerLocalization.getLanguage();
        String isocode = registerLanguage.getIsocode();

        LabelAttribute registerLabelAttribute = new LabelAttribute();
        registerLabelAttribute.setLanguage(isocode);
        registerLabelAttribute.setValue(registerLocalization.getLabel());
        registerStandard.setLabel(registerLabelAttribute);

        StringUtils stringUtils = new StringUtils();

        if (registerLocalization.getDefinition() != null) {
            DefinitionAttribute definitionAttribute = new DefinitionAttribute();
            definitionAttribute.setLanguage(isocode);

            String definition = stringUtils.replaceSpecialCharacters(registerLocalization.getDefinition());
            definitionAttribute.setValue(definition);
            registerStandard.setDefinition(definitionAttribute);
        }

        if (registerLocalization.getDescription() != null) {
            DescriptionAttribute descriptionAttribute = new DescriptionAttribute();
            descriptionAttribute.setLanguage(isocode);

            String description = stringUtils.replaceSpecialCharacters(registerLocalization.getDescription());
            descriptionAttribute.setValue(description);
            registerStandard.setDescription(descriptionAttribute);
        }

        registerStandard.setLanguage(registerLanguage);

        LocalizationMgr localizationMgr = new LocalizationMgr(em);
        /**
         * owner
         */
        Reference registerOwner = register.getRegisterowner();
        ReferenceAttribute ownerReferenceAttribute = new ReferenceAttribute();
        ownerReferenceAttribute.setUuid(registerOwner.getUuid());
        ownerReferenceAttribute.setEmail(registerOwner.getEmail());
        ownerReferenceAttribute.setReftype(registerOwner.getReftype());
        ownerReferenceAttribute.setDatecreation(registerOwner.getDatecreation());
        ownerReferenceAttribute.setDatelastupdate(registerOwner.getDatelastupdate());

        String ownerRegisterLabelFromLocaliation;
        LabelAttribute ownerLabelAttribute = new LabelAttribute();
        Localization ownerLocalization;
        try {
            ownerLocalization = localizationMgr.findByReferenceAndLanguagecode(registerOwner, registerLanguage);
            ownerRegisterLabelFromLocaliation = ownerLocalization.getLabel();
            ownerLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            ownerLocalization = localizationMgr.findByReferenceAndLanguagecode(registerOwner, masterLanguage);
            ownerRegisterLabelFromLocaliation = ownerLocalization.getLabel();
            ownerLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        ownerReferenceAttribute.setUri(ownerLocalization.getUri());

        ownerLabelAttribute.setValue(ownerRegisterLabelFromLocaliation);
        ownerReferenceAttribute.setLabel(ownerLabelAttribute);
        registerStandard.setRegisterowner(ownerReferenceAttribute);

        /**
         * manager
         */
        Reference registerManager = register.getRegistermanager();
        ReferenceAttribute managerReferenceAttribute = new ReferenceAttribute();
        managerReferenceAttribute.setUuid(registerManager.getUuid());
        managerReferenceAttribute.setEmail(registerManager.getEmail());
        managerReferenceAttribute.setReftype(registerManager.getReftype());
        managerReferenceAttribute.setDatecreation(registerManager.getDatecreation());
        managerReferenceAttribute.setDatelastupdate(registerManager.getDatelastupdate());

        String managerRegisterLabelFromLocaliation;
        LabelAttribute managerLabelAttribute = new LabelAttribute();
        Localization managerLocalization;
        try {
            managerLocalization = localizationMgr.findByReferenceAndLanguagecode(registerManager, registerLanguage);
            managerRegisterLabelFromLocaliation = managerLocalization.getLabel();
            managerLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            managerLocalization = localizationMgr.findByReferenceAndLanguagecode(registerManager, masterLanguage);
            managerRegisterLabelFromLocaliation = managerLocalization.getLabel();
            managerLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        managerReferenceAttribute.setUri(managerLocalization.getUri());

        managerLabelAttribute.setValue(managerRegisterLabelFromLocaliation);
        managerReferenceAttribute.setLabel(managerLabelAttribute);
        registerStandard.setRegistermanager(managerReferenceAttribute);

        /**
         * control body
         */
        Reference controlBody = register.getRegistercontrolbody();
        ReferenceAttribute controlBodyReferenceAttribute = new ReferenceAttribute();
        controlBodyReferenceAttribute.setUuid(controlBody.getUuid());
        controlBodyReferenceAttribute.setEmail(controlBody.getEmail());
        controlBodyReferenceAttribute.setReftype(controlBody.getReftype());
        controlBodyReferenceAttribute.setDatecreation(controlBody.getDatecreation());
        controlBodyReferenceAttribute.setDatelastupdate(controlBody.getDatelastupdate());

        String controlBodyRegisterLabelFromLocaliation;
        LabelAttribute controlBodyLabelAttribute = new LabelAttribute();
        Localization controlBodyLocalization;
        try {
            controlBodyLocalization = localizationMgr.findByReferenceAndLanguagecode(controlBody, registerLanguage);
            controlBodyRegisterLabelFromLocaliation = controlBodyLocalization.getLabel();
            controlBodyLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            controlBodyLocalization = localizationMgr.findByReferenceAndLanguagecode(controlBody, masterLanguage);
            controlBodyRegisterLabelFromLocaliation = controlBodyLocalization.getLabel();
            controlBodyLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        controlBodyReferenceAttribute.setUri(controlBodyLocalization.getUri());

        controlBodyLabelAttribute.setValue(controlBodyRegisterLabelFromLocaliation);
        controlBodyReferenceAttribute.setLabel(controlBodyLabelAttribute);
        registerStandard.setRegistercontrolbody(controlBodyReferenceAttribute);

        /**
         * submitter
         */
        Reference submitter = register.getSubmitter();
        ReferenceAttribute submitterReferenceAttribute = new ReferenceAttribute();
        submitterReferenceAttribute.setUuid(submitter.getUuid());
        submitterReferenceAttribute.setEmail(submitter.getEmail());
        submitterReferenceAttribute.setReftype(submitter.getReftype());
        submitterReferenceAttribute.setDatecreation(submitter.getDatecreation());
        submitterReferenceAttribute.setDatelastupdate(submitter.getDatelastupdate());

        String submitterRegisterLabelFromLocaliation;
        LabelAttribute submitterLabelAttribute = new LabelAttribute();
        Localization submitterLocalization;
        try {
            submitterLocalization = localizationMgr.findByReferenceAndLanguagecode(submitter, registerLanguage);
            submitterRegisterLabelFromLocaliation = submitterLocalization.getLabel();
            submitterLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            submitterLocalization = localizationMgr.findByReferenceAndLanguagecode(submitter, masterLanguage);
            submitterRegisterLabelFromLocaliation = submitterLocalization.getLabel();
            submitterLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        submitterReferenceAttribute.setUri(submitterLocalization.getUri());

        submitterLabelAttribute.setValue(submitterRegisterLabelFromLocaliation);
        submitterReferenceAttribute.setLabel(submitterLabelAttribute);
        registerStandard.setSubmitter(submitterReferenceAttribute);

        /**
         * contact point
         */
        Reference contactpoint = register.getContactpoint();
        ReferenceAttribute contactpointReferenceAttribute = new ReferenceAttribute();
        contactpointReferenceAttribute.setUuid(contactpoint.getUuid());
        contactpointReferenceAttribute.setEmail(contactpoint.getEmail());
        contactpointReferenceAttribute.setReftype(contactpoint.getReftype());
        contactpointReferenceAttribute.setDatecreation(contactpoint.getDatecreation());
        contactpointReferenceAttribute.setDatelastupdate(contactpoint.getDatelastupdate());

        String contactpointRegisterLabelFromLocaliation;
        LabelAttribute contactpointLabelAttribute = new LabelAttribute();
        Localization contactPointLocalization;
        try {
            contactPointLocalization = localizationMgr.findByReferenceAndLanguagecode(contactpoint, registerLanguage);
            contactpointRegisterLabelFromLocaliation = contactPointLocalization.getLabel();
            contactpointLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            contactPointLocalization = localizationMgr.findByReferenceAndLanguagecode(contactpoint, masterLanguage);
            contactpointRegisterLabelFromLocaliation = contactPointLocalization.getLabel();
            contactpointLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        contactpointReferenceAttribute.setUri(contactPointLocalization.getUri());

        contactpointLabelAttribute.setValue(contactpointRegisterLabelFromLocaliation);
        contactpointReferenceAttribute.setLabel(contactpointLabelAttribute);
        registerStandard.setContactpoint(contactpointReferenceAttribute);

        /**
         * license
         */
        Reference license = register.getLicense();
        ReferenceAttribute licenseReferenceAttribute = new ReferenceAttribute();
        licenseReferenceAttribute.setUuid(license.getUuid());
        licenseReferenceAttribute.setEmail(license.getEmail());
        licenseReferenceAttribute.setReftype(license.getReftype());
        licenseReferenceAttribute.setDatecreation(license.getDatecreation());
        licenseReferenceAttribute.setDatelastupdate(license.getDatelastupdate());

        String licenseRegisterLabelFromLocaliation;
        LabelAttribute licenseLabelAttribute = new LabelAttribute();
        Localization referenceLanguageLocalization;
        try {
            referenceLanguageLocalization = localizationMgr.findByReferenceAndLanguagecode(license, registerLanguage);
            licenseRegisterLabelFromLocaliation = referenceLanguageLocalization.getLabel();
            licenseLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            referenceLanguageLocalization = localizationMgr.findByReferenceAndLanguagecode(license, masterLanguage);
            licenseRegisterLabelFromLocaliation = referenceLanguageLocalization.getLabel();
            licenseLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        licenseReferenceAttribute.setUri(referenceLanguageLocalization.getUri());

        licenseLabelAttribute.setValue(licenseRegisterLabelFromLocaliation);
        licenseReferenceAttribute.setLabel(licenseLabelAttribute);
        registerStandard.setLicence(licenseReferenceAttribute);

        Registry registry = register.getRegistry();
        RegistryAttribute registryAttribute = new RegistryAttribute();

        LabelAttribute registryLabelAttribute = new LabelAttribute();
        Localization registryLocalization = localizationMgr.findByRegistryAndLanguagecode(registry, registerLanguage);
        String registryIsocode = isocode;
        if (registryLocalization == null) {
            registryLocalization = localizationMgr.findByRegistryAndLanguagecode(registry, masterLanguage);
            registryIsocode = masterLanguage.getIsocode();
        }
        registryLabelAttribute.setValue(registryLocalization.getLabel());
        registryLabelAttribute.setLanguage(registryIsocode);

        registryAttribute.setLabel(registryLabelAttribute);
        registryAttribute.setUri(registry.getBaseuri() + "/" + registry.getUriname());

        registerStandard.setRegistry(registryAttribute);

        RegisterItemStandardList registerItemStandardList = new RegisterItemStandardList();
        ArrayList<ItemStandard> itemStandardList = new ArrayList<ItemStandard>();
        ItemMgr itemMgr = new ItemMgr(em);
        List<Item> items = itemMgr.findItemsForRegister(register);
        for (Item item : items) {
            Localization itemLocalization;
            try {
                itemLocalization = localizationMgr.findByItemAndLanguagecode(item, registerLanguage);
            } catch (Exception ex) {
                itemLocalization = localizationMgr.findByItemAndLanguagecode(item, masterLanguage);
            }

            CreateItemStandardUtil createItemStandardUtil = new CreateItemStandardUtil(em);
            ItemStandard itemStandard = createItemStandardUtil.createMiniItemStandard(item, itemLocalization, registerLanguage);
            if (itemStandard.getVersionnumber() == 0) {
                itemStandardList.add(itemStandard);
            }
        }

        registerItemStandardList.setItemStandard(itemStandardList);

        registerStandard.setRegisterItemLabelList(registerItemStandardList);
        return registerStandard;
    }

    private File createXMLRegisterFile(RegisterStandard registerStandard, Register register) {
        String isocode = registerStandard.getLabel().getLanguage();

        String registerFolderStandardPath = folderStandardStaticizer + folderSeparator + register.getUriname();
        String registerFolderCustomPath = folderCustomStaticizer + folderSeparator + register.getUriname();
        File registerStandardFolder = new File(registerFolderStandardPath);
        File registercustomFolder = new File(registerFolderCustomPath);

        if (!registerStandardFolder.exists()) {
            registerStandardFolder.mkdirs();
        }
        if (!registercustomFolder.exists()) {
            registercustomFolder.mkdirs();
        }

        String registerUriname = register.getUriname();
        String registerStandardFilePath = registerStandardFolder + folderSeparator + registerUriname + "." + isocode + ".xml";
        File registerStandardFile = new File(registerStandardFilePath);

        try {
            /**
             * STANDARD XML
             */
            JAXBContext jaxbContextLang = JAXBContext.newInstance(RegisterStandard.class);
            Marshaller marshallerclassLanguage = jaxbContextLang.createMarshaller();
            marshallerclassLanguage.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            marshallerclassLanguage.marshal(registerStandard, registerStandardFile);
            log.info("Create with success: " + registerStandardFile);

            /**
             * CUSTOM XML, JSON, HTML, ATOM, RDF
             */
            for (String ext : staticizeFiles.getCreateStandardFiles().getEXTENSIONS()) {
                try {
                    String registerXSL = staticizeFiles.getStaticizerXSLFolder() + "/" + ext + "/" + registerUriname + "_register." + ext + ".xsl";
                    String registerCustomFilePath = registercustomFolder + folderSeparator + registerUriname + "." + isocode + "." + ext;

                    File finalOutFile = new File(registerCustomFilePath);
                    finalOutFile.createNewFile();
                    File transformerFile = new File(registerXSL);

                    TransformerFactoryImpl factory = new net.sf.saxon.TransformerFactoryImpl();
                    Transformer transformer = factory.newTransformer(new StreamSource(transformerFile));
                    transformer.transform(new StreamSource(registerStandardFile), new StreamResult(finalOutFile));

                    log.info("Create with success: " + finalOutFile);

                } catch (Exception ex) {
                    log.error("Error in creation the transformation file: " + ex.getMessage());
                }
            }
        } catch (JAXBException ex) {
            log.error("Error in creation file: " + registerStandardFile + " -JAXBException- " + ex.getMessage());
        }

        return registercustomFolder;
    }
}
