/*
 * Copyright 2010,2015 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 30/03/2015
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.marshaller;

import eu.europa.ec.re3gistrycommon.managers.LanguagecodeMgr;
import eu.europa.ec.re3gistrycommon.managers.LocalizationMgr;
import eu.europa.ec.re3gistrycommon.managers.RegisterMgr;
import eu.europa.ec.re3gistrycommon.managers.RegistryMgr;
import eu.europa.ec.re3gistrycommon.model.Languagecode;
import eu.europa.ec.re3gistrycommon.model.Localization;
import eu.europa.ec.re3gistrycommon.model.Reference;
import eu.europa.ec.re3gistrycommon.model.Register;
import eu.europa.ec.re3gistrycommon.model.Registry;
import eu.europa.ec.re3gistrycommon.utils.StringUtils;
import eu.europa.ec.re3gistrystaticizer.StaticizeFiles;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.RegisterStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.RegistryStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DefinitionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DescriptionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.LabelAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.ReferenceAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.RegistryAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.RegisterStandardList;
import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.persistence.EntityManager;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.transform.Transformer;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import net.sf.saxon.TransformerFactoryImpl;

public class RegistryStaticizer {

    private final EntityManager em;

    private final String folderSeparator;
    private final String folderStandardStaticizer;

    private final String folderCustomStaticizer;
    private final StaticizeFiles staticizeFiles;

    private final List<Languagecode> allLanguagecode;
    private final Languagecode masterLanguage;

    private static org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);

    /**
     *
     * @param staticizeFiles
     * @param em
     * @throws java.lang.Exception
     */
    public RegistryStaticizer(StaticizeFiles staticizeFiles, EntityManager em) throws Exception {
        this.staticizeFiles = staticizeFiles;
        this.folderSeparator = staticizeFiles.getFolderSeparator();
        this.folderStandardStaticizer = staticizeFiles.getCreateStandardFiles().getFolderStandardStaticizer();
        this.folderCustomStaticizer = staticizeFiles.getCreateStandardFiles().getFolderCustomStaticizer();

        this.em = em;

        LanguagecodeMgr languagecodeMgr = new LanguagecodeMgr(em);
        allLanguagecode = languagecodeMgr.findAll();

        masterLanguage = languagecodeMgr.getMasterLanguagecode();
    }

    public List<File> addRegistryFiles() {
        List<File> list = new ArrayList<File>();
        if (staticizeFiles.getCreateStandardFiles().getEXTENSIONS().length != 0 && !staticizeFiles.getCreateStandardFiles().getEXTENSIONS()[0].equals("")) {
            try {
                RegistryMgr registryMgr = new RegistryMgr(em);
                List<Registry> registryList = registryMgr.findAll();

                for (Iterator<Registry> it = registryList.iterator(); it.hasNext();) {
                    Registry registry = it.next();

                    LocalizationMgr localizationMgr = new LocalizationMgr(em);
                    for (Languagecode languagecode : allLanguagecode) {
                        String isocode = languagecode.getIsocode();
                        Localization registryLocalization;
                        try {
                            registryLocalization = localizationMgr.findByRegistryAndLanguagecode(registry, languagecode);
                        } catch (Exception ex) {
                            registryLocalization = localizationMgr.findByRegistryAndLanguagecode(registry, masterLanguage);
                            isocode = masterLanguage.getIsocode();
                        }
                        RegistryStandard registryStandard = createRegistry(registry, registryLocalization);
                        list.add(createXMLRegistryFile(registryStandard, isocode));
                    }
                }
            } catch (Exception ex) {
                log.error(ex.getMessage());
            }
        }
        return list;
    }

    public RegistryStandard createRegistry(Registry registry, Localization registryLocalization) throws Exception {
        RegistryStandard registryStandard = new RegistryStandard();
        registryStandard.setUuid(registry.getUuid());

        registryStandard.setBaseuri(registry.getBaseuri());
        registryStandard.setUriname(registry.getUriname());
        registryStandard.setUri(registry.getBaseuri() + "/" + registry.getUriname());
        registryStandard.setUristandard(registry.getBaseuri() + "/" + registry.getUriname());

        String language = registryLocalization.getLanguage().getIsocode();

        registryStandard.setLanguage(registryLocalization.getLanguage());

        LabelAttribute registryLabelAttribute = new LabelAttribute();
        registryLabelAttribute.setLanguage(language);
        registryLabelAttribute.setValue(registryLocalization.getLabel());
        registryStandard.setLabel(registryLabelAttribute);

        StringUtils stringUtils = new StringUtils();

        if (registryLocalization.getDefinition() != null) {
            DefinitionAttribute registryDefinitionAttribute = new DefinitionAttribute();
            registryDefinitionAttribute.setLanguage(language);

            String definition = stringUtils.replaceSpecialCharacters(registryLocalization.getDefinition());
            registryDefinitionAttribute.setValue(definition);
            registryStandard.setDefinition(registryDefinitionAttribute);
        }

        if (registryLocalization.getDescription() != null) {
            DescriptionAttribute registryDescriptionAttribute = new DescriptionAttribute();
            registryDescriptionAttribute.setLanguage(language);

            String description = stringUtils.replaceSpecialCharacters(registryLocalization.getDescription());
            registryDescriptionAttribute.setValue(description);
            registryStandard.setDescription(registryDescriptionAttribute);
        }

        LocalizationMgr localizationMgr = new LocalizationMgr(em);
        Reference registryManager = registry.getRegistrymanager();
        ReferenceAttribute registermanagerReferenceAttribute = new ReferenceAttribute();
        registermanagerReferenceAttribute.setUuid(registryManager.getUuid());
        registermanagerReferenceAttribute.setUri(registryLocalization.getUri());
        registermanagerReferenceAttribute.setEmail(registryManager.getEmail());
        registermanagerReferenceAttribute.setReftype(registryManager.getReftype());
        registermanagerReferenceAttribute.setDatecreation(registryManager.getDatecreation());
        registermanagerReferenceAttribute.setDatelastupdate(registryManager.getDatelastupdate());

        String registerLabelFromLocaliation;
        LabelAttribute labelAttribute = new LabelAttribute();
        try {
            registerLabelFromLocaliation = (localizationMgr.findByReferenceAndLanguagecode(registryManager, registryLocalization.getLanguage())).getLabel();
            labelAttribute.setLanguage(registryLocalization.getLanguage().getIsocode());
        } catch (Exception ex) {
            registerLabelFromLocaliation = (localizationMgr.findByReferenceAndLanguagecode(registryManager, masterLanguage)).getLabel();
            labelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        labelAttribute.setValue(registerLabelFromLocaliation);
        registermanagerReferenceAttribute.setLabel(labelAttribute);
        registryStandard.setRegistrymanager(registermanagerReferenceAttribute);

        registryStandard.setDatecreation(registry.getDatecreation());
        registryStandard.setDatelastupdate(registry.getDatelastupdate());

        RegisterStandardList registerStandardList = new RegisterStandardList();
        ArrayList<RegisterStandard> registerStandardArrayList = new ArrayList<RegisterStandard>();
        RegisterMgr registerMgr = new RegisterMgr(em);
        try {
            List<Register> registerList = registerMgr.findAll();

            for (Iterator<Register> it = registerList.iterator(); it.hasNext();) {
                Register register = it.next();

                Localization registerLocalization;
                try {
                    registerLocalization = localizationMgr.findByRegisterAndLanguagecode(register, registryLocalization.getLanguage());
                } catch (Exception ex) {
                    registerLocalization = localizationMgr.findByRegisterAndLanguagecode(register, masterLanguage);
                    language = masterLanguage.getIsocode();
                }

                RegisterStandard registerStandard = addRegisterStandard(register, registryLocalization.getLanguage(), registerLocalization, registryLabelAttribute, registry);
                registerStandardArrayList.add(registerStandard);
            }
        } catch (Exception ex) {
            Logger.getLogger(RegistryStaticizer.class.getName()).log(Level.SEVERE, null, ex);
        }
        registerStandardList.setRegisterStandard(registerStandardArrayList);
        registryStandard.setRegisterStandardList(registerStandardList);

        return registryStandard;
    }

    private RegisterStandard addRegisterStandard(Register register, Languagecode registerLanguage, Localization registerLocalization, LabelAttribute registryLabelAttribute, Registry registry) throws Exception {
        String language = registerLanguage.getIsocode();
        RegisterStandard registerStandard = new RegisterStandard();
        registerStandard.setUuid(register.getUuid());
        registerStandard.setBaseuri(register.getBaseuri());
        registerStandard.setUriname(register.getUriname());
        registerStandard.setUri(register.getBaseuri() + "/" + register.getUriname());
        registerStandard.setUristandard(register.getBaseuri() + "/" + register.getUriname());

        registerStandard.setDatecreation(register.getDatecreation());
        registerStandard.setDatelastupdate(register.getDatelastupdate());

        LabelAttribute registerLabelAttribute = new LabelAttribute();
        registerLabelAttribute.setLanguage(language);
        registerLabelAttribute.setValue(registerLocalization.getLabel());
        registerStandard.setLabel(registerLabelAttribute);

        registerStandard.setLanguage(registerLocalization.getLanguage());

        StringUtils stringUtils = new StringUtils();

        DefinitionAttribute registerDefinitionAttribute = new DefinitionAttribute();
        registerDefinitionAttribute.setLanguage(language);

        String definition = stringUtils.replaceSpecialCharacters(registerLocalization.getDefinition());
        registerDefinitionAttribute.setValue(definition);
        registerStandard.setDefinition(registerDefinitionAttribute);

        DescriptionAttribute registerDescriptionAttribute = new DescriptionAttribute();
        registerDescriptionAttribute.setLanguage(language);

        String description = stringUtils.replaceSpecialCharacters(registerLocalization.getDescription());
        registerDescriptionAttribute.setValue(description);
        registerStandard.setDescription(registerDescriptionAttribute);

        LocalizationMgr localizationMgr = new LocalizationMgr(em);
        /**
         * owner
         */
        Reference registerOwner = register.getRegisterowner();
        ReferenceAttribute ownerReferenceAttribute = new ReferenceAttribute();
        ownerReferenceAttribute.setUuid(registerOwner.getUuid());
        ownerReferenceAttribute.setEmail(registerOwner.getEmail());
        ownerReferenceAttribute.setReftype(registerOwner.getReftype());
        ownerReferenceAttribute.setDatecreation(registerOwner.getDatecreation());
        ownerReferenceAttribute.setDatelastupdate(registerOwner.getDatelastupdate());

        String ownerRegisterLabelFromLocaliation;
        LabelAttribute ownerLabelAttribute = new LabelAttribute();
        Localization ownerLocalization;
        try {
            ownerLocalization = localizationMgr.findByReferenceAndLanguagecode(registerOwner, registerLanguage);
            ownerRegisterLabelFromLocaliation = ownerLocalization.getLabel();
            ownerLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            ownerLocalization = localizationMgr.findByReferenceAndLanguagecode(registerOwner, masterLanguage);
            ownerRegisterLabelFromLocaliation = ownerLocalization.getLabel();
            ownerLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        ownerReferenceAttribute.setUri(ownerLocalization.getUri());

        ownerLabelAttribute.setValue(ownerRegisterLabelFromLocaliation);
        ownerReferenceAttribute.setLabel(ownerLabelAttribute);
        registerStandard.setRegisterowner(ownerReferenceAttribute);

        /**
         * manager
         */
        Reference registerManager = register.getRegistermanager();
        ReferenceAttribute managerReferenceAttribute = new ReferenceAttribute();
        managerReferenceAttribute.setUuid(registerManager.getUuid());
        managerReferenceAttribute.setEmail(registerManager.getEmail());
        managerReferenceAttribute.setReftype(registerManager.getReftype());
        managerReferenceAttribute.setDatecreation(registerManager.getDatecreation());
        managerReferenceAttribute.setDatelastupdate(registerManager.getDatelastupdate());

        String managerRegisterLabelFromLocaliation;
        LabelAttribute managerLabelAttribute = new LabelAttribute();
        Localization managerLocalization;
        try {
            managerLocalization = localizationMgr.findByReferenceAndLanguagecode(registerManager, registerLanguage);
            managerRegisterLabelFromLocaliation = managerLocalization.getLabel();
            managerLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            managerLocalization = localizationMgr.findByReferenceAndLanguagecode(registerManager, masterLanguage);
            managerRegisterLabelFromLocaliation = managerLocalization.getLabel();
            managerLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        managerReferenceAttribute.setUri(managerLocalization.getUri());

        managerLabelAttribute.setValue(managerRegisterLabelFromLocaliation);
        managerReferenceAttribute.setLabel(managerLabelAttribute);
        registerStandard.setRegistermanager(managerReferenceAttribute);

        /**
         * control body
         */
        Reference controlBody = register.getRegistercontrolbody();
        ReferenceAttribute controlBodyReferenceAttribute = new ReferenceAttribute();
        controlBodyReferenceAttribute.setUuid(controlBody.getUuid());
        controlBodyReferenceAttribute.setEmail(controlBody.getEmail());
        controlBodyReferenceAttribute.setReftype(controlBody.getReftype());
        controlBodyReferenceAttribute.setDatecreation(controlBody.getDatecreation());
        controlBodyReferenceAttribute.setDatelastupdate(controlBody.getDatelastupdate());

        String controlBodyRegisterLabelFromLocaliation;
        LabelAttribute controlBodyLabelAttribute = new LabelAttribute();
        Localization controlBodyLocalization;
        try {
            controlBodyLocalization = localizationMgr.findByReferenceAndLanguagecode(controlBody, registerLanguage);
            controlBodyRegisterLabelFromLocaliation = controlBodyLocalization.getLabel();
            controlBodyLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            controlBodyLocalization = localizationMgr.findByReferenceAndLanguagecode(controlBody, masterLanguage);
            controlBodyRegisterLabelFromLocaliation = controlBodyLocalization.getLabel();
            controlBodyLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        controlBodyReferenceAttribute.setUri(controlBodyLocalization.getUri());

        controlBodyLabelAttribute.setValue(controlBodyRegisterLabelFromLocaliation);
        controlBodyReferenceAttribute.setLabel(controlBodyLabelAttribute);
        registerStandard.setRegistercontrolbody(controlBodyReferenceAttribute);

        /**
         * submitter
         */
        Reference submitter = register.getSubmitter();
        ReferenceAttribute submitterReferenceAttribute = new ReferenceAttribute();
        submitterReferenceAttribute.setUuid(submitter.getUuid());
        submitterReferenceAttribute.setEmail(submitter.getEmail());
        submitterReferenceAttribute.setReftype(submitter.getReftype());
        submitterReferenceAttribute.setDatecreation(submitter.getDatecreation());
        submitterReferenceAttribute.setDatelastupdate(submitter.getDatelastupdate());

        String submitterRegisterLabelFromLocaliation;
        LabelAttribute submitterLabelAttribute = new LabelAttribute();
        Localization submitterLocalization;
        try {
            submitterLocalization = localizationMgr.findByReferenceAndLanguagecode(submitter, registerLanguage);
            submitterRegisterLabelFromLocaliation = submitterLocalization.getLabel();
            submitterLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            submitterLocalization = localizationMgr.findByReferenceAndLanguagecode(submitter, masterLanguage);
            submitterRegisterLabelFromLocaliation = submitterLocalization.getLabel();
            submitterLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        submitterReferenceAttribute.setUri(submitterLocalization.getUri());

        submitterLabelAttribute.setValue(submitterRegisterLabelFromLocaliation);
        submitterReferenceAttribute.setLabel(submitterLabelAttribute);
        registerStandard.setSubmitter(submitterReferenceAttribute);

        /**
         * contact point
         */
        Reference contactpoint = register.getContactpoint();
        ReferenceAttribute contactpointReferenceAttribute = new ReferenceAttribute();
        contactpointReferenceAttribute.setUuid(contactpoint.getUuid());
        contactpointReferenceAttribute.setEmail(contactpoint.getEmail());
        contactpointReferenceAttribute.setReftype(contactpoint.getReftype());
        contactpointReferenceAttribute.setDatecreation(contactpoint.getDatecreation());
        contactpointReferenceAttribute.setDatelastupdate(contactpoint.getDatelastupdate());

        String contactpointRegisterLabelFromLocaliation;
        LabelAttribute contactpointLabelAttribute = new LabelAttribute();
        Localization contactPointLocalization;
        try {
            contactPointLocalization = localizationMgr.findByReferenceAndLanguagecode(contactpoint, registerLanguage);
            contactpointRegisterLabelFromLocaliation = contactPointLocalization.getLabel();
            contactpointLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            contactPointLocalization = localizationMgr.findByReferenceAndLanguagecode(contactpoint, masterLanguage);
            contactpointRegisterLabelFromLocaliation = contactPointLocalization.getLabel();
            contactpointLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        contactpointReferenceAttribute.setUri(contactPointLocalization.getUri());

        contactpointLabelAttribute.setValue(contactpointRegisterLabelFromLocaliation);
        contactpointReferenceAttribute.setLabel(contactpointLabelAttribute);
        registerStandard.setContactpoint(contactpointReferenceAttribute);

        /**
         * license
         */
        Reference license = register.getLicense();
        ReferenceAttribute licenseReferenceAttribute = new ReferenceAttribute();
        licenseReferenceAttribute.setUuid(license.getUuid());
        licenseReferenceAttribute.setEmail(license.getEmail());
        licenseReferenceAttribute.setReftype(license.getReftype());
        licenseReferenceAttribute.setDatecreation(license.getDatecreation());
        licenseReferenceAttribute.setDatelastupdate(license.getDatelastupdate());

        String licenseRegisterLabelFromLocaliation;
        LabelAttribute licenseLabelAttribute = new LabelAttribute();
        Localization referenceLanguageLocalization;
        try {
            referenceLanguageLocalization = localizationMgr.findByReferenceAndLanguagecode(license, registerLanguage);
            licenseRegisterLabelFromLocaliation = referenceLanguageLocalization.getLabel();
            licenseLabelAttribute.setLanguage(registerLanguage.getIsocode());
        } catch (Exception ex) {
            referenceLanguageLocalization = localizationMgr.findByReferenceAndLanguagecode(license, masterLanguage);
            licenseRegisterLabelFromLocaliation = referenceLanguageLocalization.getLabel();
            licenseLabelAttribute.setLanguage(masterLanguage.getIsocode());
        }
        licenseReferenceAttribute.setUri(referenceLanguageLocalization.getUri());

        licenseLabelAttribute.setValue(licenseRegisterLabelFromLocaliation);
        licenseReferenceAttribute.setLabel(licenseLabelAttribute);
        registerStandard.setLicence(licenseReferenceAttribute);

        RegistryAttribute registryAttribute = new RegistryAttribute();
        registryAttribute.setLabel(registryLabelAttribute);
        registryAttribute.setUri(registry.getBaseuri() + "/" + registry.getUriname());
        registerStandard.setRegistry(registryAttribute);
        return registerStandard;
    }

    private File createXMLRegistryFile(RegistryStandard registryStandard, String isocode) {
        String registryStandardFolderPath = folderStandardStaticizer;
        String registryCustomFolderPath = folderCustomStaticizer;
        File registryStandardFolder = new File(registryStandardFolderPath);
        File registryCustomFolder = new File(registryCustomFolderPath);

        if (!registryStandardFolder.exists()) {
            registryStandardFolder.mkdirs();
        }
        if (!registryCustomFolder.exists()) {
            registryCustomFolder.mkdirs();
        }

        String registry = registryStandard.getUriname();
        String registryFilePath = registryStandardFolder.getAbsolutePath() + folderSeparator + registry + "." + isocode + ".xml";
        File registryFile = new File(registryFilePath);

        try {
            /**
             * STANDARD XML
             */
            JAXBContext jaxbContextLang = JAXBContext.newInstance(RegistryStandard.class);
            Marshaller marshallerclassLanguage = jaxbContextLang.createMarshaller();
            marshallerclassLanguage.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            marshallerclassLanguage.marshal(registryStandard, registryFile);
            log.info("Create with success: " + registryFile);

            /**
             * CUSTOM XML, JSON, HTML, ATOM, RDF
             */
            for (String ext : staticizeFiles.getCreateStandardFiles().getEXTENSIONS()) {
                try {
                    String registryXSL = staticizeFiles.getStaticizerXSLFolder() + "/" + ext + "/" + registry + "." + ext + ".xsl";
                    String finalOutputPath = registryFile.getAbsolutePath().replace("standard", "custom").replace("xml", ext);

                    File finalOutFile = new File(finalOutputPath);
                    finalOutFile.createNewFile();
                    File transformerFile = new File(registryXSL);

                    TransformerFactoryImpl factory = new net.sf.saxon.TransformerFactoryImpl();
                    Transformer transformer = factory.newTransformer(new StreamSource(transformerFile));
                    transformer.transform(new StreamSource(registryFile), new StreamResult(finalOutFile));
                    log.info("Create with success: " + finalOutFile);
                } catch (Exception ex) {
                    log.error("Error in creation the transformation file: " + ex.getMessage());
                }
            }
        } catch (JAXBException ex) {
            log.error("Error in creation file: " + registryFile + " -JAXBException- " + ex.getMessage());
        }

        return registryCustomFolder;
    }
}
