/*
 * Copyright 2010,2015 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 30/03/2015
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.marshaller;

import eu.europa.ec.re3gistrycommon.managers.LocalizationMgr;
import eu.europa.ec.re3gistrycommon.managers.RegistryMgr;
import eu.europa.ec.re3gistrycommon.model.Localization;
import eu.europa.ec.re3gistrycommon.model.Registry;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.filescreation.CreateSOLRFiles;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.RegistryStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.collection.ContainerCollectionRegistryStandard;
import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.persistence.EntityManager;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.transform.Transformer;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import net.sf.saxon.TransformerFactoryImpl;

public class SolrRegistryStaticizer {

    private final EntityManager em;

    private final String folderSolrStaticizer;
    private final String folderSolrcustomStaticizer;
    private final CreateSOLRFiles createSOLRFiles;

    private final String folderSeparator = System.getProperty("file.separator");

    private static org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);

    /**
     *
     * @param createSOLRFiles
     * @param em
     */
    public SolrRegistryStaticizer(CreateSOLRFiles createSOLRFiles, EntityManager em) {
        this.createSOLRFiles = createSOLRFiles;
        this.folderSolrStaticizer = createSOLRFiles.getFolderSolrStaticizer();
        this.folderSolrcustomStaticizer = createSOLRFiles.getFolderSolrCustomStaticizer();

        this.em = em;
    }

    public ArrayList<RegistryStandard> addRegistryFiles() throws Exception {
        RegistryStaticizer registryStaticizer = new RegistryStaticizer(createSOLRFiles.getStaticizeFiles(), em);
        ArrayList<RegistryStandard> registryStandardArrayList = new ArrayList<RegistryStandard>();
        try {
            RegistryMgr registryMgr = new RegistryMgr(em);
            List<Registry> registryList = registryMgr.findAll();

            for (Iterator<Registry> it = registryList.iterator(); it.hasNext();) {
                Registry registry = it.next();

                LocalizationMgr localizationMgr = new LocalizationMgr(em);
                List<Localization> registryLocalizationList = localizationMgr.findRegistryLocalization(registry);

                for (Iterator<Localization> it1 = registryLocalizationList.iterator(); it1.hasNext();) {
                    Localization registryLocalization = it1.next();
                    registryStandardArrayList.add(registryStaticizer.createRegistry(registry, registryLocalization));
                }
            }
        } catch (Exception ex) {
            log.error(ex.getMessage());
        }
        return registryStandardArrayList;
    }

    public File createSOLRRegistryFile(ContainerCollectionRegistryStandard containerCollectionRegistryStandard) {
        String registrySolrFolderPath = folderSolrStaticizer;
        String registrySolrcustomFolderPath = folderSolrcustomStaticizer;
        File registrySolrFolder = new File(registrySolrFolderPath);
        File registrySolrcustomFolder = new File(registrySolrcustomFolderPath);

        if (!registrySolrFolder.exists()) {
            registrySolrFolder.mkdirs();
        }
        if (!registrySolrcustomFolder.exists()) {
            registrySolrcustomFolder.mkdirs();
        }

        String registry = "registry";
        String registryFilePath = registrySolrFolder.getAbsolutePath() + folderSeparator + registry + ".xml";
        File registryFile = new File(registryFilePath);

        try {
            /**
             * STANDARD XML
             */
            JAXBContext jaxbContextLang = JAXBContext.newInstance(ContainerCollectionRegistryStandard.class);
            Marshaller marshallerclassLanguage = jaxbContextLang.createMarshaller();
            marshallerclassLanguage.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            marshallerclassLanguage.marshal(containerCollectionRegistryStandard, registryFile);
            log.info("Create with success: " + registryFile);

            /**
             * CUSTOM SOLR
             */
            for (String ext : createSOLRFiles.getEXTENSIONSSOLR()) {
                try {
                    String registryXSL = createSOLRFiles.getStaticizeFiles().getStaticizerXSLFolder() + "/" + ext + "/" + registry + "." + ext + ".xsl";
//                    String finalOutputPath = registryFile.getAbsolutePath().replace("solr", "solrcustom");
                    String finalOutputPath = registrySolrcustomFolder + folderSeparator + registry + ".xml";

                    File finalOutFile = new File(finalOutputPath);
                    finalOutFile.createNewFile();
                    File transformerFile = new File(registryXSL);

                    TransformerFactoryImpl factory = new net.sf.saxon.TransformerFactoryImpl();
                    Transformer transformer = factory.newTransformer(new StreamSource(transformerFile));
                    transformer.transform(new StreamSource(registryFile), new StreamResult(finalOutFile));

                    log.info("Create with success: " + finalOutFile);
                } catch (Exception ex) {
                    log.error("Error in creation the transformation file: " + ex.getMessage());
                }
            }

        } catch (JAXBException ex) {
            log.error("Error in creation file: " + registryFile + " -JAXBException- " + ex.getMessage());
        }

        return registrySolrcustomFolder;
    }
}
