/*
 * Copyright 2010,2015 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 30/03/2015
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-dev@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 * (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
 */
package eu.europa.ec.re3gistrystaticizer.vargenerator;

import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import java.io.File;
import java.util.Properties;
import org.apache.commons.io.FileUtils;

public class VarGenerator {

    private static final long serialVersionUID = 1L;
    private static final String KEY_URI_PREFIX = "var.prefix.uri";
    private static final String KEY_LANGUAGE_PREFIX = "var.prefix.language";
    private static final String KEY_TYPE_PREFIX = "var.prefix.type";
    private static String uriPrefix;
    private static String languagePrefix;
    private static String typePrefix;
    private static String lineSeparator;
    private static String folderSeparator;
    private static org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);
    private final Properties properties;

    public VarGenerator() throws Exception {
        properties = eu.europa.ec.re3gistrycommon.utils.Configuration.getInstance().getProperties(Constants.MODULE_NAME);

        /**
         * Getting properties
         */
        uriPrefix = properties.getProperty(KEY_URI_PREFIX, "URI:");
        languagePrefix = properties.getProperty(KEY_LANGUAGE_PREFIX, "Content-language:");
        typePrefix = properties.getProperty(KEY_TYPE_PREFIX, "Content-type:");
        lineSeparator = System.getProperty("line.separator");
        folderSeparator = System.getProperty("file.separator");
    }

    public void writeVar(File folder) throws Exception {
        File[] fileList = folder.listFiles();
        String toVar = "";
        /**
         * For each file item in this folder
         */
        for (File file : fileList) {
            /**
             * Check if the file item is a file
             */
            if (file.isFile()) {
                /**
                 * Splitting the filename (pattern
                 * <filename>.<languagecode>.<extension>)
                 */
                String[] tmp = file.getName().split("\\.");
                if (tmp.length > 2) {
                    /**
                     * Getting the language code and the extension
                     */
                    String type = tmp[tmp.length - 1];
                    String language = tmp[tmp.length - 2];

                    /**
                     * Creating the var string for this file (language and
                     * extension information are taken from the properties file)
                     */
                    toVar += uriPrefix + " " + file.getName() + lineSeparator;
                    toVar += languagePrefix + " " + properties.getProperty("content.language." + language) + lineSeparator;
                    toVar += typePrefix + " " + properties.getProperty("content.type." + type) + lineSeparator;
                    toVar += lineSeparator;
                }
            }
        }
        /**
         * Writing the .var file
         */
        File var = new File(folder.getAbsolutePath() + folderSeparator + "cn.var");
        FileUtils.writeStringToFile(var, toVar);
        log.info("Create with success: " + var.getAbsolutePath());
    }
}
